@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,6 +25,7 @@
 #include "DicomDirectoryComponent.h"
 #include "gdcmImageReader.h"
 #include "vtkGDCMImageReader.h"
+#include "gdcmAttribute.h"
 
 // Qt includes
 #include <QDir>
@@ -40,36 +41,54 @@ using namespace gdcm;
 DicomDirectoryComponent::DicomDirectoryComponent(const QString & path) throw(AbortException) : ImageComponent(path)
 {
     // Use GDCM libraries to handle dicom volume image files
-    vtkGDCMImageReader *reader = vtkGDCMImageReader::New();
-    
+    vtkGDCMImageReader *imageReader = vtkGDCMImageReader::New(); // reader to construct the image as a vtk image data
+    gdcm::Reader *reader = new gdcm::Reader(); // reader to get header with tags from the DICOM images and fix image data according
+
     // Get all the files inside the directory
     QDir dir;
     dir.setCurrent(path);
     dir.setFilter(QDir::Files);
     QStringList files = dir.entryList();
-    
+
     // indicate to the gdcm reader to read a list of files
     vtkSmartPointer<vtkStringArray> fileNames = vtkSmartPointer<vtkStringArray>::New();
     foreach(QString file, files)
         fileNames->InsertNextValue(file.toStdString().c_str());
-    
+    imageReader->SetFileNames(fileNames);
+    reader->SetFileName(files.first().toAscii());
+
     // read the bunch of files using gdcm
-    reader->SetFileNames(fileNames);
+    imageReader->Update();
+    reader->Read();
     
-    // read the file(s)
-    reader->UpdateWholeExtent();
-        
-    // Get the image pixels value from the gdcm reader
-    vtkSmartPointer<vtkImageData> image = reader->GetOutput();
+    // Get the data spacing. 
+    // The ZSpacing, corresponding to the Slice thickness is wrong, as it is not read from its DICOM tag.
+    double *spacing = imageReader->GetDataSpacing();
     
+    // Get slice thickness information from the header of the DICOM image
+    File file = reader->GetFile();
+    gdcm::DataSet ds = file.GetDataSet();
+    Attribute<0x0018, 0x0050> at; // Tag 0018 0050 => Slice Thickness
+    at.Set(ds);
+    spacing[2] = at.GetValue(); // spacing[2] => z-spacing.
+    
+    // vtkGDCMImageReader class doesn't consider correctly slice-thickness
+    // Thus, we need to use this class to preserve the z-spacing in the volumic reconstructed image
+    // For more information, see official example : http://gdcm.sourcearchive.com/documentation/2.0.14-4/TestvtkGDCMImageReader2_8cxx-source.html
+    vtkImageChangeInformation *imageInfoChanger = vtkImageChangeInformation::New();
+    imageInfoChanger->SetInput(imageReader->GetOutput());
+    imageInfoChanger->SetOutputSpacing(spacing[0], spacing[1], spacing[2]);
+    imageInfoChanger->Update();
+
+    vtkSmartPointer<vtkImageData> image = imageInfoChanger->GetOutput();
+
     // load the image into CamiTK
     setImageData(image, false);
-    
+
     // use gdcm reader to provide good information for the lut
-    // we need to set up range and table values
     double range[2] = {0.0, 0.0};
-    reader->GetOutput()->GetScalarRange(range);
-    this->getLut()->SetRange(range);
+    imageReader->GetOutput()->GetScalarRange(range);
+    this->getLut()->SetRange(range);  // we need to set up range and table values
     this->getLut()->SetNumberOfTableValues(abs(range[0]) + abs(range[1]));
 }
 
