@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -571,7 +571,7 @@ void SofaSimulator::createPml(const char* inputFile, const char* pmlFile) { //TO
     //one component for hexas or quads (if exist) for each component
     //one component for tetras or triangles (if exist) for each component
     for (unsigned int i = 0; i < mechanicalObjects.size(); i++) {
-        if (getMechanicalObject(i)) { // some are null (e.g. olg model!)
+        if (getMechanicalObject(i) && /*case mecaObj without topology*/mechanicalObjects[i]->getContext()->getMeshTopology()) { // some are null (e.g. olg model!)
             //external surface
             SurfaceExtractor extract=SurfaceExtractor(pm);
             extract.init();
