@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -92,7 +92,6 @@ void ImageLutWidget::updateComponent(ImageComponent * comp) {
 
     myComponent = comp;
 
-
     // if there is no lookup table, just don't display this widget!
     if (myComponent->getLut() == NULL) {
         setEnabled(false);
@@ -105,33 +104,26 @@ void ImageLutWidget::updateComponent(ImageComponent * comp) {
     invert = false;
 
     // initialize the sliders value
-//    int nbOfColors = myComponent->getLut()->GetNumberOfTableValues();
     double * imgRange = myComponent->getImageData()->GetScalarRange();
     double imgMinColor = imgRange[0];
     double imgMaxColor = imgRange[1];
-
-
-
-//	double imgMinColor = myComponent->getImageData()->get GetScalarTypeMin();
-//	double imgMaxColor = myComponent->getImageData()->GetScalarTypeMax();
     double nbColorsOrg = imgMaxColor - imgMinColor;
     long int nbOfColors = (long int) (nbColorsOrg);
 
     // as this widget is only grayscale, compute the average of the color values
-//    lutMin = myComponent->getImageData()->GetScalarTypeMin();
-//    lutMax = myComponent->getImageData()->GetScalarTypeMax();
     lutMin = imgMinColor;
     lutMax = imgMaxColor;
 
     // update scale and table value information on the luts
-    nbHistoBins = abs(lutMin) + abs(lutMax);
+    if ((unsigned)abs(lutMax - lutMin) > UINT_MAX)
+        nbHistoBins = UINT_MAX;
+    else
+        nbHistoBins = abs(lutMax - lutMin);
     myComponent->getLut()->SetNumberOfTableValues(nbHistoBins);
-    myComponent->getLut()->SetLevel((imgMinColor + imgMaxColor) /2);
-    myComponent->getLut()->SetWindow((imgMaxColor - imgMinColor) /2);
 
     blockAllSignals ( true );
     initLevelGUI(lutMin, lutMax, myComponent->getLut()->GetLevel());
-    initWindowGUI( 0, ( lutMax - lutMin ), myComponent->getLut()->GetWindow());
+    initWindowGUI( 0, myComponent->getLut()->GetWindow(), myComponent->getLut()->GetWindow());
 
     // allocate memory to draw the histogram according to the number of available scalar component
     // free memory of previously drawn histogram if the lut widget handle another component
@@ -139,8 +131,7 @@ void ImageLutWidget::updateComponent(ImageComponent * comp) {
         delete greyLevels;
 
     // allocate the memory needed for that component
-    greyLevels = new unsigned int[nbHistoBins + 1];
-
+    greyLevels = new double[nbHistoBins + 1];
 
     // check alpha state for min and max
     double * color = myComponent->getLut()->GetTableValue(0);
@@ -177,8 +168,6 @@ void ImageLutWidget::applyLUT() {
     int nbOfColors = myComponent->getLut()->GetNumberOfTableValues();
     QColor fadedColor = ui.minColor->palette().button().color();
     QColor strongColor = ui.maxColor->palette().button().color();
-    //QColor strongColor(ui.lineEditRed->text().toInt(), ui.lineEditGreen->text().toInt(), ui.lineEditBlue->text().toInt());
-    //QColor fadedColor = QColor::fromRgbF(strongColor.redF() / double(nbOfColors), strongColor.greenF() / double(nbOfColors), strongColor.blueF() / double(nbOfColors));
     QColor maxColor, minColor;
     if (!invert) {
         minColor = fadedColor;
@@ -226,7 +215,7 @@ void ImageLutWidget::draw () {
 
     //-- initialize histogram values to 0
     for (unsigned int i = 0; i < nbHistoBins; i++ )
-        greyLevels[i] = 0;
+        greyLevels[i] = 0.0;
 
     //-- get image volume
     vtkSmartPointer<vtkImageData> data;
@@ -289,8 +278,11 @@ void ImageLutWidget::draw () {
     pen.setColor(palette().background().color());
 
     //-- background color
-//     QRectF sceneRectangle(0.0, 0.0, 250.0, 250.0); <-- old rectangle for 0->255 pixel values
-    QRectF sceneRectangle(lutMin, 0.0, nbHistoBins, highestGreyLevel);
+    // Scaling the graphic view is needed: in case highestGreyLevel is greater than max int on Win 32bits
+    // Qt paint canvas bug crashes. When using Qt5, try to remove the scaling code to see if the bug has been fixed.
+    double defaultHeight = 256.0;
+    double scalingFactor = defaultHeight/highestGreyLevel;
+    QRectF sceneRectangle(lutMin, 0.0, nbHistoBins, defaultHeight);
 
     //-- draw color table
     QLinearGradient colorGradient(sceneRectangle.x(), sceneRectangle.height() / 2.0, sceneRectangle.width(), sceneRectangle.height() / 2.0);
@@ -307,7 +299,6 @@ void ImageLutWidget::draw () {
     ui.histogramGraphicsView->scene()->addItem(sceneRectItem);
 
     //-- show transparency
-    //BEGIN
     double window = myComponent->getLut()->GetWindow();
     double level = myComponent->getLut()->GetLevel();
     if (ui.maxTransparency->isChecked()) {
@@ -322,16 +313,14 @@ void ImageLutWidget::draw () {
             ui.histogramGraphicsView->scene()->addRect(sceneRectangle.x(), sceneRectangle.y(), minCorner.x(), sceneRectangle.height(), pen, QBrush(palette().window()));
         }
     }
-    //END
 
     //-- draw histogram
-    //BEGIN
     qreal barHeight;
     qreal barWidth = 1.0; //sceneRectangle.width() / double(nbHistoBins);
     double x = sceneRectangle.x();
     QPainterPath histogramPath(QPointF(x, sceneRectangle.height()));
     for (unsigned int i = 0; i < nbHistoBins; i++ ) {
-        barHeight = greyLevels[i]; // * sceneRectangle.height() / double(highestGreyLevel);
+        barHeight = greyLevels[i]*scalingFactor;
         histogramPath.lineTo(x, sceneRectangle.height() - barHeight);
         x += barWidth;
     }
@@ -345,18 +334,13 @@ void ImageLutWidget::draw () {
     pen.setStyle(Qt::DashLine);
 
     // pen width depends on numbers of bars in the histogram
-    int penWidth = (int)((double)nbHistoBins / 100.0);
-    //END
-
-//     pen.setWidth(2);
+    int penWidth = (int)(sceneRectangle.width() / 100.0);
     pen.setWidth(penWidth);
 
     ui.histogramGraphicsView->scene()->addLine(level, sceneRectangle.y(), level, sceneRectangle.height(), pen);
 
     pen.setStyle(Qt::SolidLine);
     // create the proper path for the LUT
-    //BEGIN
-    // QPointF leftCorner(sceneRectangle.x() + level - window / 2.0, sceneRectangle.height());
     QPointF leftCorner(level - window / 2.0, sceneRectangle.height());
     QPointF rightCorner(level + window / 2.0, sceneRectangle.y());
     QPainterPath path;
@@ -364,7 +348,6 @@ void ImageLutWidget::draw () {
     path.lineTo(leftCorner);
     path.lineTo(rightCorner);
     path.lineTo(sceneRectangle.width(), sceneRectangle.y());
-    //END
 
     pen.setWidth(penWidth);
     ui.histogramGraphicsView->scene()->addPath(path, pen);
@@ -378,21 +361,29 @@ void ImageLutWidget::draw () {
 template<class DATATYPE>
 void ImageLutWidget::fillHistogramTable(DATATYPE * data, unsigned int dataDim, DATATYPE minVal, DATATYPE maxVal) {
     // scale factor from [min,max] to [0..nbHistoBins]
-    DATATYPE intervalLength = (DATATYPE) ((maxVal - minVal) / nbHistoBins);
+    DATATYPE intervalLength = (DATATYPE) ((maxVal - minVal) / (DATATYPE)nbHistoBins);
+        
+    if( intervalLength ) 
+    {
+        //-- build histogram
+        for (unsigned int i = 0; i < dataDim; i++ ) {
+            // Find the corresponding interval index
+            unsigned int pointIndex = (unsigned int) ((data[i] - minVal) / intervalLength);
+            // build the histogram (increment the corresponding value)
+            greyLevels[pointIndex] += 1.0;
+        }
 
-    //-- build histogram
-    for (unsigned int i = 0; i < dataDim; i++ ) {
-        // Find the corresponding interval index
-        unsigned int pointIndex = (unsigned int) ((data[i] - minVal) / intervalLength);
-        // build the histogram (increment the corresponding value)
-        greyLevels[pointIndex] += 1;
+        //-- compute max value
+        highestGreyLevel = 0;
+        for (unsigned int i = 0; i<nbHistoBins; i++) {
+            if (greyLevels[i] > highestGreyLevel)
+                 highestGreyLevel = greyLevels[i];
+        }
     }
-
-    //-- compute max value
-    highestGreyLevel = 0;
-    for (unsigned int i = 0; i<nbHistoBins; i++) {
-        if (greyLevels[i] > highestGreyLevel)
-            highestGreyLevel = greyLevels[i];
+    else
+    {
+        QString msg = "Division by zero";
+        CAMITK_ERROR("ImageLutWidget", "fillHistogramTable", msg.toStdString());
     }
 }
 
@@ -540,3 +531,4 @@ void ImageLutWidget::blockAllSignals(bool block) {
     ui.minColor->blockSignals(block);
     ui.maxColor->blockSignals(block);
 }
+
