@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -53,12 +53,16 @@
 #include <ImageComponent.h>
 
 /**
+ * @ingroup group_sdk_actions_image_lut
+ * 
+ * @brief
  * The class ImageLutWidget defines a widget controling the Look Up Table of
  *  an instance of ImageComponent.
  *
+ * @note
  * The ui is defined in the corresponding ImageLutWidget.ui
- *
- */
+ *  
+ */ 
 class ImageLutWidget : public QWidget {
     Q_OBJECT
 
@@ -144,13 +148,13 @@ private:
     /// Min the possible data value (given by the data type of the image)
     double lutMax;
 
-    /// Table containing histogram bins
-    unsigned int  * greyLevels;
+    /// Table containing histogram bins \note use double as it can have a high number of pixel of the same number
+    double * greyLevels;
 
-    /// highest number of grey level (highest value in greyLevels array)
-    unsigned int highestGreyLevel;
+    /// highest number of grey level (highest value in greyLevels array) \note use double as it can have a high number of pixel of the same number
+    double highestGreyLevel;
 
-    /// size of greyLevels
+    /// size of greyLevels \note the maximum number of histogram bins is UINT_MAX
     unsigned int nbHistoBins;
 
     /// does the user asked for an invert LUT
