@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -208,12 +208,12 @@ void MeshQuality::updateMeshColor(vtkSmartPointer< vtkDoubleArray > qualityArray
         indices = elementsMap[VTK_TRIANGLE];
     } else if(elementsComboBox->currentText() =="Quads") {
         indices = elementsMap[VTK_QUAD];
-    } else if (elementsComboBox->currentText() == "Hexahedra"){
+    } else if (elementsComboBox->currentText() == "Hexahedra") {
         indices = elementsMap[VTK_HEXAHEDRON];
-    }else if (elementsComboBox->currentText() == "Tetrahedra"){
+    } else if (elementsComboBox->currentText() == "Tetrahedra") {
         indices = elementsMap[VTK_TETRA];
     }
-    
+
     if (indices.size()>0 && elementsMap.size()==1) {
         vtkSmartPointer<vtkFloatArray> cellData = vtkSmartPointer<vtkFloatArray>::New();
         for (unsigned int i = 0; i< indices.size(); i++) {
@@ -276,7 +276,9 @@ void MeshQuality::updateTableWidget(vtkSmartPointer< vtkDoubleArray > qualityArr
     // resize the table
     qualityInfo->setRowCount(indices.size());
 
-    double min = VTK_DOUBLE_MAX, max = VTK_DOUBLE_MIN, avg = 0.0;
+    minV = VTK_DOUBLE_MAX;
+    maxV = VTK_DOUBLE_MIN;
+    double avg = 0.0;
     for(unsigned int i = 0; i < indices.size(); i++) {
         vtkIdType id;
         id=i;
@@ -289,10 +291,10 @@ void MeshQuality::updateTableWidget(vtkSmartPointer< vtkDoubleArray > qualityArr
         itemQ->setData(Qt::DisplayRole, val);
         qualityInfo->setItem(i, 1, itemQ);
         avg += val;
-        if (val<min)
-            min = val;
-        if (val>max)
-            max = val;
+        if (val<minV)
+            minV = val;
+        if (val>maxV)
+            maxV = val;
     }
 
     qualityInfo->setSortingEnabled(true);
@@ -300,8 +302,8 @@ void MeshQuality::updateTableWidget(vtkSmartPointer< vtkDoubleArray > qualityArr
 
     avg /= indices.size();
 
-    QString elementInfo =  "&nbsp;&nbsp;> Minimum: " + QString("%1").arg(min,6) + "<br/>";
-    elementInfo += "&nbsp;&nbsp;> Maximum: " + QString("%1").arg(max,6) + "<br/>";
+    QString elementInfo =  "&nbsp;&nbsp;> Minimum: " + QString("%1").arg(minV,6) + "<br/>";
+    elementInfo += "&nbsp;&nbsp;> Maximum: " + QString("%1").arg(maxV,6) + "<br/>";
     elementInfo += "&nbsp;&nbsp;> Average: " + QString("%1").arg(avg,6) + "<br/>";
     //-- update the element info label
     elementInfoLabel->setText(elementInfo);
@@ -320,34 +322,45 @@ void MeshQuality::updateTableWidget(vtkSmartPointer< vtkDoubleArray > qualityArr
 
 // -----------------getQualityColor---------------------------------------------------------------------
 double MeshQuality::getQualityColor(double val, double minAR, double maxAR, double minNR, double maxNR) {
-    double xa,xb,ya,yb,u,v;
+//     double xa,xb,ya,yb,u,v;
+    double xmin, xmax;
+    bool sideMin = true;
 
-    if (val>=minAR && val<=maxAR) {
+    if (val>=minNR && val<=maxNR) {
         //acceptable value
-        return 1;
-    } else if(val<=minNR || val>=maxNR) {
-        //bad value
-        return 0;
-    } else if(val>minNR && val<minAR) {
-        xa = minAR;
-        ya = 1;
-        xb = minNR;
-        yb = 0;
-    } else if (val>maxAR && val<maxNR) {
-        xa = maxAR;
-        ya = 1;
-        xb = maxNR;
-        yb = 0;
+        if(val>=minAR && val <=maxAR) {
+            //good good and re-good value = blue
+            return 0;
+        } else if (val<minAR) {
+            xmax = minAR;
+            if (minNR==VTK_DOUBLE_MIN) {
+                xmin = minV;
+            } else {
+                xmin = minNR;
+            }
+        } else if (val>maxAR) {
+            sideMin = false;
+            xmin = maxAR;
+            if (maxNR = VTK_DOUBLE_MAX) {
+                xmax = maxV;
+            } else {
+                xmax = maxNR;
+            }
+        } else {
+            //should never arrive
+            std::cerr<<"MeshQuality:: Problem in value interpretation"<<std::endl;
+        }
     } else {
-        //should never arrive
-        std::cerr<<"ERROR in color interpolation"<<std::endl;
-        return 0;
+        //bad value = red
+        return 1;
     }
-    //-- Compute interpolation lines ux+v=y
-    u = (yb-ya)/(xb-xa);
-    v = -u*xa+ya;
+    double dist = xmax - xmin;
+    double temp = xmax - val;
+    double res = fabs(temp/dist);
+    if (!sideMin)
+        res = 1-res;
     // result is ranged between [0;1] to interpolate a color between [blue;red]
-    return std::fabs(val*u+v);
+    return res;
 }
 
 // ------------------------------------------computeTrisQuality-------------------------------------------------
