@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -84,7 +84,8 @@ ActionStateMachine::ActionStateMachine(int &argc, char ** argv, QString inputFil
     this->checkSCXMLFile(filename);
 
     QDateTime now = QDateTime::currentDateTime();
-    QString newDir = now.toString("yyyy-MM-dd") + "T" + now.toString("hh:mm:ss");
+    // NOTE on Windows ":" (colon) is reserved by the system for separating drive names, therefore hh:mm:ss cannot be used
+    QString newDir = now.toString("yyyy-MM-dd") + "T" + now.toString("hh-mm-ss"); 
 
     if (! saveDirectory.mkdir(newDir))  {
         saveDirectory = QFileDialog::getExistingDirectory(this->mainWindow, "Please select a directory where to save log and component files");
@@ -355,9 +356,10 @@ void ActionStateMachine::createTransitions(QDomNodeList nodeList) throw(AbortExc
                     QDomNodeList compsToClose = toClose.item(0).toElement().elementsByTagName("camitk:component");
                     for (int idx = 0; idx < compsToClose.size(); idx++) {
                         QDomElement oneComp = compsToClose.item(idx).toElement();
+                        QString forceOn = oneComp.attribute("force","false");
                         QString compName = oneComp.attribute("name");
                         QString compType = oneComp.attribute("type");
-                        trans->addComponentToClose(compName, compType);
+                        trans->addComponentToClose(compName, compType, QVariant(forceOn).toBool());
                     }
                 }
             }
