@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -86,13 +86,13 @@ int main(int argc, char *argv[]) {
             }
             else if (o.printPath()) {
                 // init the camitk application context without auto-loading all extensions
-                Application a("config", argc, argv, false);
+                Application a("camitk-config", argc, argv, false);
                 std::cout << Core::getPaths().toStdString() << std::endl;
                 return EXIT_SUCCESS;
             }
             else if (o.camitkDir()) {
                 // init the camitk application context without auto-loading all extensions
-                Application a("config", argc, argv, false);
+                Application a("camitk-config", argc, argv, false);
                 std::cout << Core::getGlobalInstallDir().toStdString() << std::endl;
                 return EXIT_SUCCESS;
             }
@@ -104,7 +104,7 @@ int main(int argc, char *argv[]) {
             }
             else {
                 usage(argv[0]);
-                //NO GUI for the time being
+                //TODO: Show some GUI (for e.g. with "copy to clipboard" and "email" buttons)
                 //return a.exec();
                 return EXIT_SUCCESS;
             }
