@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -165,6 +165,12 @@ void ImpMainWindow::initActions() {
     editApplicationSettings->setStatusTip ( tr ( "Edit the preferences" ) );
     editApplicationSettings->setWhatsThis ( tr ( "Preferences\n\nEdit the settings and preferences of imp" ) );
     connect ( editApplicationSettings, SIGNAL ( triggered() ), this, SLOT ( editSettings() ) );
+    
+    // save history as SCXML
+    saveHistory = new QAction(tr("&Save history"), this);
+    saveHistory->setStatusTip(tr("Save the history of actions processed as an SCXML file."));
+    saveHistory->setWhatsThis(tr("Save the history of actions processed as an SCXML file."));
+    connect(saveHistory, SIGNAL(triggered()), this, SLOT(saveHistoryAsSCXML()));
 
     //--- actions of the View menu
     viewMenuBar = new QAction ( tr ( "Menu bar" ), this );
@@ -220,6 +226,8 @@ void ImpMainWindow::initMenuBar() {
     fileMenu->addAction ( fileSave );
     fileMenu->addAction ( fileSaveAs );
     fileMenu->addAction ( fileSaveAll );
+    fileMenu->addSeparator();
+    fileMenu->addAction(saveHistory);
     fileMenu->addAction ( recentDocumentSeparator );
 
     foreach(QAction *recentAction, recentDocumentActions) {
@@ -229,12 +237,14 @@ void ImpMainWindow::initMenuBar() {
     fileMenu->addSeparator();
     fileMenu->addSeparator();
     fileMenu->addAction ( fileQuit );
+    
 
     // -- edit
     QMenu * editMenu = new QMenu ( tr ( "&Edit" ) );
     editMenu->addAction ( editClearSelection );
     editMenu->addSeparator();
     editMenu->addAction ( editApplicationSettings );
+    
 
     // -- View menu
     viewMenu = new QMenu ( tr ( "&View" ) );
@@ -425,7 +435,7 @@ void ImpMainWindow::openDirectory ( QAction *emitter ) {
         }
         else {
             // TODO add to recent document and manage directories as recent documents
-            statusBar()->showMessage ( tr ( QString("Directory " + dir + " successfuly loaded" ).toStdString().c_str()) );
+            statusBar()->showMessage ( tr ( QString("Directory " + dir + " successfully loaded" ).toStdString().c_str()) );
 
             // refresh all
             refresh();
@@ -561,6 +571,12 @@ void ImpMainWindow::updateRecentDocumentsMenu() {
     }
 }
 
+// ------------------------------ saveHistoryAsSCXML -------------------------------
+void ImpMainWindow::saveHistoryAsSCXML()
+{
+    Application::saveHistoryAsSXML();
+}
+
 
 
 
