@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -30,11 +30,14 @@
 
 // -- Core stuff
 #include <MainWindow.h>
-
 /**
-  * This Class describes the "historical" imp application.
-  * It is a classical desktop application, with  menubar, toolbar and statusbar.
-  */
+ * @ingroup group_sdk_application_imp
+ * 
+ * @brief
+ * This Class describes the "historical" imp application.
+ * It is a classical desktop application, with  menubar, toolbar and statusbar.
+ *
+ */
 class ImpMainWindow : public camitk::MainWindow {
     Q_OBJECT
 
@@ -100,6 +103,9 @@ public slots:
 
     /// show or hide the status bar
     void showStatusBar(bool);
+    
+    /// Save the history of action as a SCXML file
+    void saveHistoryAsSCXML();
 
     ///@}
 
@@ -179,6 +185,7 @@ private:
     /// edit actions
     QAction *editApplicationSettings;
     QAction *editClearSelection;
+    QAction *saveHistory;
     ///@}
 
     /** @name Other menu attributes */
@@ -211,11 +218,13 @@ private:
     QAction *recentDocumentSeparator;
 
     ///@}
+    
+    
 private slots:
 
     /// open a given recent document
     void openRecentDocuments();
-
+ 
 };
 
 #endif //IMP_MAINWINDOW_H
