@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -22,12 +22,7 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
-/**
- * @file MshExtension.cpp
- * @brief Component class implementation for .msh files.
- * @author Mathieu BAILET
- * @date July 5 2012
- */
+
 
 #include "MshComponent.h"
 
@@ -64,7 +59,7 @@ MshComponent::MshComponent(const QString & file) throw(AbortException) : MeshCom
     double pt[3];
     vtkSmartPointer<vtkUnstructuredGrid> mesh = vtkSmartPointer<vtkUnstructuredGrid>::New();
 
-    nbElements = 0;
+    long nbCells = 0;
 
     //build the vtkPoinSet from the file
     vtkSmartPointer<vtkPoints> points = vtkSmartPointer<vtkPoints>::New();
@@ -145,7 +140,7 @@ MshComponent::MshComponent(const QString & file) throw(AbortException) : MeshCom
         }
 
         mesh->InsertNextCell(vtkEltTypeId, idList);
-        nbElements++;
+        nbCells++;
     }
 
     mesh->Update();
@@ -156,59 +151,4 @@ MshComponent::MshComponent(const QString & file) throw(AbortException) : MeshCom
     // add the represention in the 3D viewer
     setVisibility(InteractiveViewer::get3DViewer(), true);
 
-    // initialize the dynamic properties
-    initDynamicProperties();
-}
-
-// -------------------- initDynamicProperties --------------------
-void MshComponent::initDynamicProperties() {
-    // add a dynamic property to manage the surface color
-    //setProperty("position point #1", QVector3D(1.0,0.0,0.0));
-    vtkUnstructuredGrid* mesh = dynamic_cast< vtkUnstructuredGrid* >(getPointSet().GetPointer());
-    vtkSmartPointer<vtkUnsignedCharArray> types = mesh->GetCellTypesArray();
-    std::map<unsigned char, int> elementsMap;
-    std::map<unsigned char, int>::iterator elementsMapIt;
-
-    for (int i=0; i<types->GetNumberOfTuples(); i++) {
-        if (!elementsMap.count(types->GetValue(i)))
-            elementsMap[types->GetValue(i)] = 0;
-        elementsMap[types->GetValue(i)]++;
-    }
-
-    for (elementsMapIt = elementsMap.begin(); elementsMapIt != elementsMap.end(); elementsMapIt++) {
-        switch(elementsMapIt->first) {
-        case VTK_LINE :
-            setProperty("Edge", elementsMapIt->second);
-            break;
-        case VTK_TRIANGLE :
-            setProperty("Triangle", elementsMapIt->second);
-            break;
-        case VTK_TETRA :
-            setProperty("Tetra", elementsMapIt->second);
-            break;
-        case VTK_HEXAHEDRON :
-            setProperty("Hexa", elementsMapIt->second);
-            break;
-        case VTK_WEDGE :
-            setProperty("Prism", elementsMapIt->second);
-            break;
-        case VTK_PYRAMID :
-            setProperty("Pyramid", elementsMapIt->second);
-            break;
-        default :
-            setProperty("Prob", elementsMapIt->second);
-            break;
-        }
-    }
-}
-
-// -------------------- getNbPoints --------------------
-int MshComponent::getNbPoints() {
-    return getPointSet()->GetNumberOfPoints();
-}
-
-// -------------------- getNbElements --------------------
-int MshComponent::getNbElements() {
-    return nbElements;
-}
-
+}
\ No newline at end of file
