@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -22,12 +22,6 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
-/**
- * @file MshExtension.cpp
- * @brief .msh file manager class implementation.
- * @author Mathieu BAILET
- * @date July 5 2012
- */
 
 #include "MshComponent.h"
 #include "MshExtension.h"
@@ -54,7 +48,7 @@ QString MshExtension::getName() const {
 }
 
 QString MshExtension::getDescription() const {
-    return "MSH <em>.msh</em> files in <b>CamiTK</b>.(very few support!) <br>(c)TIMC-IMAG UJF 2012";
+    return "This simple MSH Component allows you to manipulate <em>.msh</em> files (initially from gmsh software). See <a href=\"http://www.geuz.org/gmsh/doc/texinfo/gmsh.html\">http://www.geuz.org/gmsh/doc/texinfo/gmsh.html</a> for more information about this format";
 }
 
 QStringList MshExtension::getFileExtensions() const {
