@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -22,51 +22,32 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
-/**
- * @file OffComponent.h
- * @brief Component class for .off files.
- * @author Sonia Selmi
- * @date July 30 2012
- */
 
 #ifndef OFF_COMPONENT_H
 #define OFF_COMPONENT_H
 
 #include <MeshComponent.h>
-
 /**
- * @class OffComponent
- * @brief The manager of the .off
- */
+ * @ingroup group_sdk_components_off
+ * 
+ * @brief 
+ * The manager of the .off
+ * 
+ **/ 
 class OffComponent : public camitk::MeshComponent {
 
     Q_OBJECT
 
 public:
 
-    Q_PROPERTY(int nbPoints READ getNbPoints);
-
-    Q_PROPERTY(int nbElements READ getNbElements);
 
     /// default constructor
     OffComponent(const QString & file) throw(camitk::AbortException);
 
-    /// methods needed to manage the read-only static properties
-    int getNbPoints();
 
-    /// total number of elements
-    int getNbElements();
 
 private:
 
-    /// create and initialize dynamic properties
-    void initDynamicProperties();
-    
-    /// number of elements (i.e., cells)
-    int nbElements;
-
-    /// number of points
-    int nbPoints;
 };
 
 #endif
