@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -37,7 +37,7 @@
 #include <QProcess>
 
 // MSVC does not have the C++ Standard rint function (it should be included in any C99 implementation)
-#if defined(_WIN32) && !defined(__MINGW32__)
+#if defined(_WIN32) && !defined(__MINGW32__) && (_MSC_VER < 1800)
 #include <math.h>
 double rint(double x) {
     // middle value point test
@@ -175,7 +175,7 @@ const QString Core::getGlobalInstallDir() {
     QByteArray camitkDirectory;
     bool processOk = false;
 
-    if (Application::getName() != "config") {
+    if (Application::getName() != "camitk-config") {
         // run camitk-imp to get the "installed" directory
         // note: camitk-imp must be in the path, or it is not considered as installed
         // (installed = available at any time)
@@ -249,13 +249,13 @@ const bool Core::isDebugBuild() {
 //
 //                     OBSOLETE PUBLIC METHODS
 //
-// TODO CAMITK_OBSOLETE. This section list all the methods marked as obsolete.
+// TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated.
 // They are to be removed in CamiTK 4.0
 // ----------------------------------------------------------------
 
 
 // ------------- getComponentDir (static) -----------------
-//TODO remove in CamiTK 4.0 CAMITK_OBSOLETE
+//TODO remove in CamiTK 4.0 CAMITK_DEPRECATED
 const QString Core::getComponentDir() {
     QDir appDir(getGlobalInstallDir());
     appDir.cd("lib/"+QString(Core::shortVersion)+"/components");
@@ -264,7 +264,7 @@ const QString Core::getComponentDir() {
 
 
 // ------------- getActionDir (static) -----------------
-//TODO remove in CamiTK 4.0 CAMITK_OBSOLETE
+//TODO remove in CamiTK 4.0 CAMITK_DEPRECATED
 const QString Core::getActionDir() {
     QDir appDir(getGlobalInstallDir());
     appDir.cd("lib/"+QString(Core::shortVersion)+"/actions");
@@ -273,7 +273,7 @@ const QString Core::getActionDir() {
 
 
 // ------------- getModuleDir (static) -----------------
-//TODO remove in CamiTK 4.0 CAMITK_OBSOLETE
+//TODO remove in CamiTK 4.0 CAMITK_DEPRECATED
 const QString Core::getModuleDir(const QString & subpath) {
     QDir appDir(getGlobalInstallDir());
     appDir.cd("lib/"+QString(Core::shortVersion)+"/" + subpath);
@@ -281,7 +281,7 @@ const QString Core::getModuleDir(const QString & subpath) {
 }
 
 // ------------- getLibDir (static) -----------------
-//TODO remove in CamiTK 4.0 CAMITK_OBSOLETE
+//TODO remove in CamiTK 4.0 CAMITK_DEPRECATED
 const QString Core::getCoreLibDir() {
     return getGlobalInstallDir();
 }
