@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -80,20 +80,24 @@ void ExtensionManager::autoload(ExtensionManager::ExtensionType type) {
     //-- remove duplicates
     QStringList extensionFileNames;
     QStringList extensionAbsoluteFileNames;
-    QMap<QString, QDir> extensionUniqueDir;
-    foreach(QString dirName, extensionDir) {
+    QMap<QString, QDir> extensionUniqueDir;    
+    foreach(QString dirName, extensionDir)
+    {
         QDir dir(dirName);
         QStringList pluginFileNames = getPluginFileNames(dir);
-        foreach(QString pluginFile, pluginFileNames) {
+        foreach(QString pluginFile, pluginFileNames) 
+        {
             QString pluginAbsoluteFileName = dir.absoluteFilePath(pluginFile);
-            if (!extensionFileNames.contains(pluginFile)) {
+            if (!extensionFileNames.contains(pluginFile)) 
+            {
                 extensionFileNames.append(pluginFile);
                 extensionUniqueDir.insert(pluginFile,dir);
                 extensionAbsoluteFileNames.append(pluginAbsoluteFileName);
             }
-            else {
+            else 
+            {
                 CAMITK_INFO("ExtensionManager", "autoload", "Warning: duplicate extension: " << pluginFile.toStdString() << " found in " << dir.absolutePath().toStdString() << ".\nUsing extension in " << extensionUniqueDir.value(pluginFile).absolutePath().toStdString() << " instead (higher priority)");
-            }
+            }                        
         }
     }
 
@@ -521,7 +525,7 @@ bool ExtensionManager::unloadComponentExtension(QString extOrName) {
 //
 //                     OBSOLETE PUBLIC METHODS
 //
-// TODO CAMITK_OBSOLETE. This section list all the methods marked as obsolete.
+// TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated.
 // They are to be removed in CamiTK 4.0
 // ----------------------------------------------------------------
 
