@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -28,18 +28,24 @@
 
 // -- Core stuff
 #include "CamiTKAPI.h"
+#include <HistoryItem.h>
 
 #include <QSet>
 #include <QWidget>
 #include <QString>
 #include <QAction>
+#include <signal.h>
 
 
 namespace camitk {
 
 class ActionExtension;
+class Property;
 
 /**
+ * @ingroup group_sdk_libraries_core_action
+ * 
+ * @brief
  * Action class is an abstract class that enables you to build a action (generally on a component).
  * At least two classes have to be reimplemented to enable the action: ActionExtension + Action
  *
@@ -145,14 +151,27 @@ class ActionExtension;
  * If there is no parent given for an embedded action, then the action is embedded in the ActionViewer by default.
  *
  * The method apply() must be implemented in your Action.
- *
+ * 
  * \note at any moment, the selected components on which the action needs to be applied
  * are available by getTargets().
  * targetComponents is filtered so that it only contains compatible components (i.e.,
  * instances of getComponent()).
+ * 
+ * \note About registering your action in the history of the application.
+ * Consider registering your action within the application's history once applied. The history of action features
+ * a stack of processed action. The application's history of actions allows to export the saved actions as an XML file for 
+ * scripting or replaying it. To do so, implement the apply() method in your code, then launch the method applyAndRegister(), 
+ * which simply wraps the apply() method with the preProcess() and postProcess() methods. You may also connect a SIGNAL to it,
+ * as the applyAndRegister() method is a Qt SLOT.
  *
- * The method applyInPipeline() performs some pre- and post-processing around the method apply().
- * It has to be used within a pipeline (a chain of actions) where setInputComponents()
+ * \note About creating a pipeline of actions
+ * A pipeline of actions is a state machine where each state stands for an action with inputs and output components. The transitions 
+ * between the states are done by processing the state's action (i.e. by calling the corresponding action's apply() method).
+ * Interpreting an pipeline of action is simpler than simply executing the action since the user doesn't need to manually
+ * set the inputs and outputs of each action (it is done automatically).
+ * If you are willing to write such a pipeline, simply implements the apply() method of each of your action and called the 
+ * applyInPipeline() (instead of simply apply()). The method applyInPipeline() performs some pre- and post-processing around 
+ * the method apply(). It has to be used within a pipeline (a chain of actions) where setInputComponents()
  * and getOutputComponents() are needed. preProcessInPipeline() only selects the right components,
  * and postProcess() sets output components and record history.
  *
@@ -183,17 +202,32 @@ public:
     };
 
 public slots:
-    /** This method triggers the action.
-     *  The parent widget is used if the action is embedded, see class description for more information about the algorithm.
-     *  This method cannot be redefined in inherited class.
+    /** 
+     * This method triggers the action.
+     * The parent widget is used if the action is embedded, see class description for more information about the algorithm.
+     * This method cannot be redefined in inherited class.
      */
     ApplyStatus trigger(QWidget * parent = NULL);
 
-    /** This method is called when the action has to be applied on the target list (get the target lists using getTargets())
-     *  \note it should never be empty!
-     *  @return status of the apply method
+    /** 
+     * This method is called when the action has to be applied on the target list (get the target lists using getTargets())
+     *  It calls the algorithm of your action on the target list of components
+     * \note it should never be empty!
+     * \note if you wish to call your action and register it within the application history, prefer
+     * using the \see Action::applyAndRegister()
+     * method
+     * @return The status of the apply method.
      */
     virtual ApplyStatus apply() = 0;
+    
+    /** 
+     * This method is called whenever the action has to be applied on the target list (like the apply()) method
+     * AND registered within the application history of actions.
+     * \note This is the default behaviour of applying and action.
+     * The application's history of actions allows to export the saved actions as an XML file for scripting or replaying it.
+     * @return The status of the apply method.
+     **/
+    ApplyStatus applyAndRegister();
 
 public:
 
@@ -208,21 +242,22 @@ public:
      *  As the method apply() is called between preProcessInPipeline() and postProcessInPipeline(), the returned value
      *  is the returned value of apply().
      */
-    virtual ApplyStatus applyInPipeline();
-
+    ApplyStatus applyInPipeline();
+    //@}
+        
     /// Specify the input Component(s)
     /// Only applyInPipeline() should be called with this method (maybe apply),
     ///  but not trigger() as its first intruction is to clear the target components list !!!
-    virtual void setInputComponents(ComponentList inputs);
+    void setInputComponents(ComponentList inputs);
 
     /// Specify the input Components in case of only one Component.
-    virtual void setInputComponent(Component * input);
+    void setInputComponent(Component * input);
 
     /// Returns the output Component(s)
-    virtual ComponentList getOutputComponents();
+    ComponentList getOutputComponents();
 
     /// Returns the output Components in case of only one Component.
-    virtual Component * getOutputComponent();
+    Component * getOutputComponent();
     //@}
 
     /// @name Generic action getters
@@ -311,6 +346,24 @@ public:
     /// are the properties to be udpated every time the user makes a change in the widget (default is false)?
     void setAutoUpdateProperties(bool);
 
+    /** Get a Property given its name
+     *  @param name the property name
+     *  @return NULL if the name does not match any property name
+     * 
+     *  @see Property
+     */
+    Q_INVOKABLE virtual Property* getProperty(QString name);
+    
+    /** Add a new parameter to the action, using the CamiTK property class.
+     * If the parameter already exist, it will just change its value.
+     * 
+     * \note
+     * The action takes ownership of the Property instance.
+     *
+     * @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated)
+     */
+    virtual bool addParameter(Property*);   
+    
 protected:
     /** @name Generic action attributes setters
      *  These methods can not be redefined in subclasses but have to used to ensure name/description unicity
@@ -344,22 +397,7 @@ protected:
 
     ///@}
 
-    /** @name Pipeline execuction of the Action
-     * These methods are called by the method applyInPipeline.
-     * In case of a pipeline application of the Action (i.e. a chain of actions with no gui),
-     * they behave as follows:
-     */
-    ///@{
-    /** Selects the right component(s) (the one that has been set by setInputComponents() ),
-     *  so that the apply method uses the right component(s) through getTargets().
-     *  If setInputComponents where not called, does not select any component.
-     */
-    virtual void preProcessInPipeline();
-
-    /** Set the right output component list so that the method getOutputComponents() can be called
-     */
-    virtual void postProcessInPipeline();
-    ///@}
+    
 
 private:
     /// the name of the action
@@ -389,6 +427,9 @@ private:
     /// the corresponding QAction
     QAction *qAction;
 
+    /// list of CamiTK property decorating the dynamic properties (action parameters)
+    QMap<QString, Property*> parameterMap;
+
     /**
      *  The list of valid (regarding the component property) components for which this action is called.
      *  This list is private (use getTargets() in subclasses).
@@ -402,16 +443,74 @@ private:
 
     /// Should the properties/parameters of this action be automatically updated when the user change something in the GUI
     bool autoUpdateProperties;
+    
+    /// @name Action history registration 
+    ///@{
+    /**
+     * This properties and methods helps registering an applied action in the history of the application.
+     * The application's history of actions allows to export the saved actions as an XML file for scripting or replaying it.
+     **/
+    
+    /**
+     * The @class{HistoryItem} associated to this action.
+     **/ 
+    HistoryItem *item;
+        
+    /** The list of top level selected components before running the action
+     *  This list is used to deduce the number of top level components, modified through applying the action
+     **/ 
+    ComponentList topLevelSelectedComponents;
+        
+    /**
+     * Save the number of top level components loaded in memory before applying the action.
+     * This allows to deduce the number of created / deleted components lauching the action.
+     */
+    void preProcess(); 
+        
+    /**
+     * Register the action in the history. The history item registered features the input and output components, 
+     * which are deduced with the preProcess() and postProcess() functions.
+     */
+    void postProcess();
+    ///@}
 
     /// @name Pipeline execuction of the Action
     ///@{
-    /// List of alive component before the application of the action
-    /// (to be compared withe the list after and deduce outputComponents.
+    /**
+     * In case of a pipeline application of the Action (i.e. a chain of actions with no gui),
+     * the following properties and methods are used:
+     */
+     
+    /** 
+     * List of alive component before the application of the action
+     * (to be compared with the list after and deduce outputComponents).
+     **/ 
     ComponentList aliveBeforeComponents;
-    /// List returned by getOutputComponents()
+    
+    /**
+     * List returned by getOutputComponents()
+     **/
     ComponentList outputComponents;
+    
+   
+    /** 
+     * Selects the right component(s) (the one that has been set by setInputComponents() ),
+     * so that the apply method uses the right component(s) through getTargets().
+     * If setInputComponents where not called, does not select any component.
+     */
+    void preProcessInPipeline();
+
+    /** 
+     * Set the right output component list so that the method getOutputComponents() can be called.
+     * Also, register the action in the history.
+     */
+    void postProcessInPipeline();
+    
+   
 
     ///@}
+    
+    
 
 };
 
