@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -30,10 +30,14 @@
 #include "MainWindow.h"
 #include "ExtensionManager.h"
 #include "Action.h"
+#include "HistoryComponent.h"
 
 // -- QT stuff
 #include <QSettings>
 #include <QMessageBox>
+#include <QFileDialog>
+#include <QDomDocument>
+#include <QTextStream>
 
 // -- VTK stuff (only for updating progress bar via vtk filters)
 #include <vtkAlgorithm.h>
@@ -309,54 +313,77 @@ Component * Application::open(const QString & fileName) {
     Component *comp = NULL;
 
     // -- Get the corresponding extension... (compatible format)
-    QString extension = QFileInfo(fileName).completeSuffix();
+    QString extension = QFileInfo(fileName).suffix();
 
     // -- ask the plugin instance to create the Component instance
     ComponentExtension * cp = ExtensionManager::getComponentExtensions().value(extension);
+    QString ext;
+
+    // -- file may be compressed so we check the complete extension
+    if (!cp) {
+        // the complete base name consists of all characters in the file up to (but not including) the last '.' character.
+        QString baseName = QFileInfo(fileName).completeBaseName();
+        ext = QFileInfo(baseName).suffix();
+        extension = ext+"."+extension;
+        cp = ExtensionManager::getComponentExtensions().value(extension);
+    }
 
     // -- check the validity of the plugin
     if (!cp) {
-        QMessageBox::warning(NULL, "ComponentExtension Opening Error...", "Cannot find the appropriate component plugin for opening:<br>" + fileName + " (extension " + extension + ")<p>To solve this problem, make sure that: <ul><li>A corresponding valid plugin is present in one of the component directories (<tt>" + Core::getComponentDirectories().join(", ") + "</tt></li><li>Your application called <tt>ComponentExtension::autoloadExtensions()</tt> before calling <tt>ComponentExtension::open(...)</tt></li></ul>");
-        return comp;
-    }
-
-    // -- ask the plugin to create the top level component
-    try {
-        // open using transformed path so that anything looking like C:\\Dir1\\Dir2\\foo.zzz is unified to a C:/Dir1/Dir2/foo.zz
-        comp = cp->open(QFileInfo(fileName).absoluteFilePath());
-
-        // -- notify the application
-        if ( comp == NULL ) {
-            showStatusBarMessage( tr ( "Error loading file:" ) + fileName );
-        }
-        else {
-            // add the document to the recent list
-            addRecentDocument(fileName);
-            showStatusBarMessage( tr ( QString("File " + fileName + " successfuly loaded").toStdString().c_str() ) );
-        }
-
         // restore the normal cursor/progress bar
         restoreOverrideCursor();
         resetProgressBar();
 
-        // refresh all viewers
-        refresh();
+        QMessageBox::warning(NULL, "ComponentExtension Opening Error...", "Cannot find the appropriate component plugin for opening:<br>" + fileName + " (extension " + extension + ")<p>To solve this problem, make sure that: <ul><li>A corresponding valid plugin is present in " + Core::getComponentDir() + "</li><li>Your application called <tt>ComponentExtension::autoloadExtensions()</tt> before calling <tt>ComponentExtension::open(...)</tt></li></ul>");
+    }
+    else {
 
-        return comp;
-    }
-    catch (AbortException & e) {
-        QMessageBox::warning(NULL, "Opening aborted...", "Extension: " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>Reason:<br>" + e.what());
-        return NULL;
-    }
-    catch (std::exception& e) {
-        QMessageBox::warning(NULL, "Opening aborted...", "Extension " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>External:<br>" + "This exception was not generated directly by the extension,<br>but by one of its dependency.<br>Reason:<br>" + e.what());
-        return NULL;
-    }
-    catch (...) {
-        QMessageBox::warning(NULL, "Opening aborted...", "Extension " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>Unknown Reason:<br>" + "This exception was not generated directly by the extension,<br>but by one of its dependency.");
-        return NULL;
+        // -- ask the plugin to create the top level component
+        try {
+            // open using transformed path so that anything looking like C:\\Dir1\\Dir2\\foo.zzz is unified to a C:/Dir1/Dir2/foo.zz
+            comp = cp->open(QFileInfo(fileName).absoluteFilePath());
+
+            // -- notify the application
+            if ( comp == NULL ) {
+                showStatusBarMessage( tr ( "Error loading file:" ) + fileName );
+            }
+            else {
+                // add the document to the recent list
+                addRecentDocument(fileName);
+                showStatusBarMessage( tr ( QString("File " + fileName + " successfully loaded").toStdString().c_str() ) );
+
+                // refresh all viewers
+                refresh();
+            }
+
+        }
+        catch (AbortException & e) {
+            // restore the normal cursor/progress bar
+            restoreOverrideCursor();
+            resetProgressBar();
+            QMessageBox::warning(NULL, "Opening aborted...", "Extension: " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>Reason:<br>" + e.what());
+            comp = NULL;
+        }
+        catch (std::exception& e) {
+            // restore the normal cursor/progress bar
+            restoreOverrideCursor();
+            resetProgressBar();
+            QMessageBox::warning(NULL, "Opening aborted...", "Extension " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>External:<br>" + "This exception was not generated directly by the extension,<br>but by one of its dependency.<br>Reason:<br>" + e.what());
+            comp = NULL;
+        }
+        catch (...) {
+            // restore the normal cursor/progress bar
+            restoreOverrideCursor();
+            resetProgressBar();
+            QMessageBox::warning(NULL, "Opening aborted...", "Extension " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>Unknown Reason:<br>" + "This exception was not generated directly by the extension,<br>but by one of its dependency.");
+            comp = NULL;
+        }
     }
 
+    // restore the normal cursor/progress bar
+    restoreOverrideCursor();
+    resetProgressBar();
+    return comp;
 }
 
 // -------------------- openDirectory --------------------
@@ -364,12 +391,12 @@ Component * Application::openDirectory(const QString & dirName, const QString &
     // set waiting cursor
     setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
 
+    Component *comp = NULL;
+
     ComponentExtension *cp = ExtensionManager::getDataDirectoryComponents().value(pluginName);
 
     if (cp != NULL) {
         // Ask the plugin instance to create the Component instance
-        Component *comp = NULL;
-
         try {
             comp = cp->open(QDir(dirName).absolutePath());
 
@@ -378,28 +405,31 @@ Component * Application::openDirectory(const QString & dirName, const QString &
                 showStatusBarMessage( tr ( "Error loading directory:" ) + dirName );
             }
             else {
-                showStatusBarMessage( tr ( QString("Directory " + dirName + " successfuly loaded").toStdString().c_str() ) );
+                showStatusBarMessage( tr ( QString("Directory " + dirName + " successfully loaded").toStdString().c_str() ) );
+                // refresh all viewers
+                refresh();
             }
-
+        }
+        catch (AbortException & e) {
             // restore the normal cursor/progress bar
             restoreOverrideCursor();
             resetProgressBar();
-
-            // refresh all viewers
-            refresh();
-            return comp;
-        }
-        catch (AbortException & e) {
             QMessageBox::warning(NULL, "Opening aborted...", "Extension: " + cp->getName() + "<br>Error: cannot open file " + dirName + "<br>Reason:<br>" + e.what());
-            return NULL;
+            comp = NULL;
         }
         catch (...) {
+            // restore the normal cursor/progress bar
+            restoreOverrideCursor();
+            resetProgressBar();
             QMessageBox::warning(NULL, "Opening aborted...", "Extension " + cp->getName() + " Error: cannot open directory " + dirName + "<br>Unknown Reason:<br>" + "This exception was not generated directly by the extension,<br>but by one of its dependency.");
             delete comp;
-            return NULL;
+            comp = NULL;
         }
     }
     else {
+        // restore the normal cursor/progress bar
+        restoreOverrideCursor();
+        resetProgressBar();
         QMessageBox::warning(NULL, "ComponentExtension Opening Error...", "Cannot find the appropriate component plugin for opening directory:<br>" + dirName
                              + "<p>To solve this problem, make sure that:<ul>"
                              +" <li>A corresponding valid plugin is present in one of the component directories: <tt>" + Core::getComponentDirectories().join(", ") + "</tt></li>"
@@ -409,8 +439,8 @@ Component * Application::openDirectory(const QString & dirName, const QString &
 
     // restore the normal cursor/progress bar
     restoreOverrideCursor();
-
-    return NULL;
+    resetProgressBar();
+    return comp;
 }
 
 // -------------------------- close ------------------------------
@@ -436,7 +466,7 @@ bool Application::close ( Component *comp ) {
         // refresh all viewers
         refresh();
 
-        showStatusBarMessage( compName + tr ( " successfuly closed..." ));
+        showStatusBarMessage( compName + tr ( " successfully closed..." ));
         return true;
     }
     else {
@@ -456,7 +486,7 @@ bool Application::save(Component* component) {
     }
 
     // Get the saving extension...
-    QString extension = QFileInfo(component->getFileName()).completeSuffix();
+    QString extension = QFileInfo(component->getFileName()).suffix();
 
     // Get the extension instance that can save the component instance (compatible format)
     ComponentExtension * cp = ExtensionManager::getComponentExtensions().value(extension);
@@ -473,7 +503,7 @@ bool Application::save(Component* component) {
         if (cp->save(component)) {
             // update the last used dir
             setLastUsedDirectory(QFileInfo(component->getFileName()).absoluteDir());
-            showStatusBarMessage( component->getName() + tr ( " successfuly saved..." ));
+            showStatusBarMessage( component->getName() + tr ( " successfully saved..." ));
             return true;
         }
         else {
@@ -697,7 +727,293 @@ HistoryItem Application::removeLastHistoryItem()
     return getHistory().pop();
 }
 
+// -------------------- saveHistoryAsSXML --------------------
+void Application::saveHistoryAsSXML()
+{
+    // Empty history => do nothing
+    if(Application::getHistory().isEmpty())
+    {
+        cerr << "No history to save, aborting ..." << endl;
+        return;
+    }
+
+    // Create the XML document
+    QDomDocument *doc = new QDomDocument();
+
+    // root element
+    QDomElement root = doc->createElement("scxml");
+    root.setAttribute("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance");
+    root.setAttribute("xmlns", "http://camitk.imag.fr/3/smallScxml");
+    root.setAttribute("xmlns:camitk", "http://camitk.imag.fr/3/asm");
+    root.setAttribute("xsi:schemaLocation", "http://camitk.imag.fr/3/smallScxml/../resources/smallScxml.xsd");
+    root.setAttribute("initial", "Initialize");
+    doc->appendChild(root);
+
+    // SXML always contains an Initialize element which describe the pipeline
+    QDomElement initializeElt = doc->createElement("state");
+    root.appendChild(initializeElt);
+    initializeElt.setAttribute("id","Initialize");
+    QDomElement initializeElt_onEntry = doc->createElement("onentry");
+    initializeElt.appendChild(initializeElt_onEntry);
+    QDomElement initializeElt_onState = doc->createElement("camitk:onState");
+    initializeElt_onEntry.appendChild(initializeElt_onState);
+    // Description of the pipeline
+    QDomElement initializeElt_desc = doc->createElement("camitk:description");
+    initializeElt_onState.appendChild(initializeElt_desc);
+    // create the pipeline description that will be filled whilel processing the history items.
+    QString pipelineDescription = "This pipeline will process several actions on the input component(s): <br /> <ul>";
+    // Transition
+    QDomElement initializeElt_transition = doc->createElement("transition");
+    initializeElt_transition.setAttribute("event", "Next");
+    initializeElt_transition.setAttribute("target", "Action 1");
+    initializeElt.appendChild(initializeElt_transition);
+    QDomElement initializeElt_transition2 = doc->createElement("transition");
+
+    // Create a list of all components created during the pipeline, to know which ones to delete once pipeline is reset
+    // by the action state machine
+    QList<HistoryComponent> allCreatedComponents;
+
+    // Main loop accross the different actions in the history
+    for(int i=0; i<Application::getHistory().size(); i++)
+    {
+        // Get the current history element, i.e. the action of the pipeline with its parameters
+        HistoryItem crtHistoryItem = Application::getHistory().at(i);
+        Action *crtAction = Application::getAction(crtHistoryItem.getName());
+        // state
+        QDomElement crtElement_state = doc->createElement("state");
+        root.appendChild(crtElement_state);
+        crtElement_state.setAttribute("id", "Action " + QString::number(i+1));
+        // onEntry
+        QDomElement crtElement_onEntry = doc->createElement("onentry");
+        crtElement_state.appendChild(crtElement_onEntry);
+        QDomElement crtElement_onState = doc->createElement("camitk:onState");
+        crtElement_onEntry.appendChild(crtElement_onState);
+
+        // action description
+        QDomElement crtElement_description = doc->createElement("camitk:description");
+        QDomText crtElement_descriptionText = doc->createTextNode(crtAction->getDescription());
+        crtElement_description.appendChild(crtElement_descriptionText);
+        crtElement_onState.appendChild(crtElement_description);
+
+        // action name & parameters
+        QDomElement crtElement_action = doc->createElement("camitk:action");
+        crtElement_onState.appendChild(crtElement_action);
+        // action name
+        QDomElement crtElement_actionName = doc->createElement("camitk:name");
+        crtElement_action.appendChild(crtElement_actionName);
+        pipelineDescription.append("<li>" + crtAction->getName() + "</li>");
+        QDomText crtElement_actionNameText = doc->createTextNode(crtAction->getName());
+        crtElement_actionName.appendChild(crtElement_actionNameText);
+        // action parameters
+        if (!crtAction->dynamicPropertyNames().isEmpty())
+        {
+            QDomElement crtElementAction_parameters = doc->createElement("camitk:parameters");
+            crtElement_action.appendChild(crtElementAction_parameters);
+            foreach (QByteArray crtParameter, crtAction->dynamicPropertyNames())
+            {
+                QDomElement crtElementAction_parameter = doc->createElement("camitk:parameter");
+                crtElementAction_parameters.appendChild(crtElementAction_parameter);
+                crtElementAction_parameter.setAttribute("name", QString(crtParameter));
+                crtElementAction_parameter.setAttribute("type", QVariant::typeToName(crtAction->property(crtParameter).type()));
+                crtElementAction_parameter.setAttribute("value", crtAction->property(crtParameter.data()).toString());
+            }
+        }
+
+        QDomElement crtElement_actionParam = doc->createElement("camitk:parameters");
+        crtElement_action.appendChild(crtElement_actionParam);
+
+        // action input components
+        if (!crtHistoryItem.getInputHistoryComponents().isEmpty())
+        {
+            QDomElement crtElement_actionInputComp = doc->createElement("camitk:inputs");
+            crtElement_action.appendChild(crtElement_actionInputComp);
+
+            for(int j=0; j<crtHistoryItem.getInputHistoryComponents().size(); j++)
+            {
+                QDomElement crtElement_crtInputComp = doc->createElement("camitk:component");
+                // determine the type of each input component (image, meshes or other)
+                HistoryComponent crtInputHistoryComp = crtHistoryItem.getInputHistoryComponents().at(j);
+                switch(crtInputHistoryComp.getType())
+                {
+                case HistoryComponent::IMAGE_COMPONENT:
+                    crtElement_crtInputComp.setAttribute("type", "ImageComponent");
+                    break;
+                case HistoryComponent::MESH_COMPONENT:
+                    crtElement_crtInputComp.setAttribute("type", "MeshComponent");
+                    break;
+                case HistoryComponent::OTHER:
+                default:
+                    crtElement_crtInputComp.setAttribute("type", "Other");
+                    break;
+                }
+                // save its name
+                crtElement_crtInputComp.setAttribute("name", crtInputHistoryComp.getName());
+
+                // save the current DOM element in the XML structure
+                crtElement_actionInputComp.appendChild(crtElement_crtInputComp);
+            }
+        }
+
+        // action output components
+        if (!crtHistoryItem.getOutputHistoryComponents().isEmpty())
+        {
+            QDomElement crtElement_actionOutputComp = doc->createElement("camitk:outputs");
+            crtElement_action.appendChild(crtElement_actionOutputComp);
+
+            for(int j=0; j<crtHistoryItem.getOutputHistoryComponents().size(); j++)
+            {
+                QDomElement crtElement_crtOuputComp = doc->createElement("camitk:component");
+                // determine the type of each input component (image, meshes or other)
+                HistoryComponent crtOutputHistoryComp = crtHistoryItem.getOutputHistoryComponents().at(j);
+                allCreatedComponents.append(crtOutputHistoryComp); // note the component created
+                switch(crtOutputHistoryComp.getType())
+                {
+                case HistoryComponent::IMAGE_COMPONENT:
+                    crtElement_crtOuputComp.setAttribute("type", "ImageComponent");
+                    break;
+                case HistoryComponent::MESH_COMPONENT:
+                    crtElement_crtOuputComp.setAttribute("type", "MeshComponent");
+                    break;
+                case HistoryComponent::OTHER:
+                default:
+                    crtElement_crtOuputComp.setAttribute("type", "Other");
+                    break;
+                }
+                // save its name
+                crtElement_crtOuputComp.setAttribute("name", crtOutputHistoryComp.getName());
+
+                // save the current DOM element in the XML structure
+                crtElement_actionOutputComp.appendChild(crtElement_crtOuputComp);
+            }
+        }
+
+        // Transitions
+        if (Application::getHistory().size() >= 1) // else, no transition at all
+        {
+            // Next transition
+            QDomElement crtElement_transitionNext = doc->createElement("transition");
+            if (i == Application::getHistory().size() - 1) // Last action element => next element = Bye element.
+                crtElement_transitionNext.setAttribute("target", "Bye");
+            else // Next generic action state
+                crtElement_transitionNext.setAttribute("target", "Action " + QString::number(i+2));
+            crtElement_transitionNext.setAttribute("event", "Next");
+            crtElement_state.appendChild(crtElement_transitionNext);
+
+            // Back transition
+            QDomElement crtElement_transitionBack = doc->createElement("transition");
+            crtElement_transitionBack.setAttribute("event", "Back");
+            if (i == 0) // Back to Initialize state
+                crtElement_transitionBack.setAttribute("target", "Initialize");
+            else // Back to previous state and delete optional created component in memory
+            {
+                crtElement_transitionBack.setAttribute("target", "Action " + QString::number(i));
+                // Verify that previsous element has not created components in memory
+                HistoryItem previousItem = Application::getHistory().at(i-1);
+                if (!previousItem.getOutputHistoryComponents().isEmpty())
+                {
+                    // Ask for deletion of each component created at the previous element
+                    QDomElement crtElementTransitionBack_onTransition =  doc->createElement("onTransition");
+                    crtElement_transitionBack.appendChild(crtElementTransitionBack_onTransition);
+                    QDomElement crtElementTransitionBack_close = doc->createElement("camitk:close");
+                    crtElementTransitionBack_onTransition.appendChild(crtElementTransitionBack_close);
+                    foreach(HistoryComponent crtComp, previousItem.getOutputHistoryComponents())
+                    {
+                        QDomElement crtElementTransitionBack_comp = doc->createElement("camitk:component");
+                        crtElementTransitionBack_close.appendChild(crtElementTransitionBack_comp);
+                        switch (crtComp.getType())
+                        {
+                        case HistoryComponent::IMAGE_COMPONENT:
+                            crtElementTransitionBack_comp.setAttribute("type", "ImageComponent");
+                            break;
+                        case HistoryComponent::MESH_COMPONENT:
+                            crtElementTransitionBack_comp.setAttribute("type", "MeshComponent");
+                            break;
+                        case HistoryComponent::OTHER:
+                        default:
+                            crtElementTransitionBack_comp.setAttribute("type", "Other");
+                            break;
+                        }
+                        crtElementTransitionBack_comp.setAttribute("name", crtComp.getName());
+                    }
+                }
+            }
+
+            crtElement_state.appendChild(crtElement_transitionBack);
+        } // End transitions
+    }
+
+    // Update description of the pipeline, now that we have filled the it!
+    initializeElt_desc.appendChild(doc->createCDATASection(pipelineDescription));
+
+    // Last element : Bye
+    QDomElement finalElt = doc->createElement("state");
+    root.appendChild(finalElt);
+    finalElt.setAttribute("id","Bye");
+    finalElt.setAttribute("final","true");
+    QDomElement finalElt_onEntry = doc->createElement("onentry");
+    finalElt.appendChild(finalElt_onEntry);
+    QDomElement finalElt_onState = doc->createElement("camitk:onState");
+    finalElt_onEntry.appendChild(finalElt_onState);
+    // Thanks !
+    QDomElement finalElt_desc = doc->createElement("camitk:description");
+    finalElt_onState.appendChild(finalElt_desc);
+    QDomCDATASection finalEltDesc;
+    finalElt_desc.appendChild(doc->createCDATASection("Thanks you for using the CamiTK Action State Machine !"));
+    // Transition
+    QDomElement finalElt_transition = doc->createElement("transition");
+    finalElt_transition.setAttribute("event", "Back to the beginning");
+    finalElt_transition.setAttribute("target", "Initialize");
+    finalElt.appendChild(finalElt_transition);
+    // Ask for deletion of all components created in the pipeline
+    if (!allCreatedComponents.isEmpty())
+    {
+        QDomElement finalEltTransition_onTransition =  doc->createElement("onTransition");
+        finalElt_transition.appendChild(finalEltTransition_onTransition);
+        QDomElement finalEltTransition_close = doc->createElement("camitk:close");
+        finalEltTransition_onTransition.appendChild(finalEltTransition_close);
+        foreach(HistoryComponent crtComp, allCreatedComponents)
+        {
+            QDomElement finalEltTransition_comp = doc->createElement("camitk:component");
+            finalEltTransition_close.appendChild(finalEltTransition_comp);
+            switch (crtComp.getType())
+            {
+            case HistoryComponent::IMAGE_COMPONENT:
+                finalEltTransition_comp.setAttribute("type", "ImageComponent");
+                break;
+            case HistoryComponent::MESH_COMPONENT:
+                finalEltTransition_comp.setAttribute("type", "MeshComponent");
+                break;
+            case HistoryComponent::OTHER:
+            default:
+                finalEltTransition_comp.setAttribute("type", "Other");
+                break;
+            }
+            finalEltTransition_comp.setAttribute("name", crtComp.getName());
+        }
+    }
+    // note, final element will automatically have a "Quit" transition, added by the action state machine.
+
+
+    // Get the xml of the tree node
+    QString xml = doc->toString();
+
+    // Write the xml to a file
+    QString outputFileName = QFileDialog::getSaveFileName(NULL, tr("Save history of actions ..."), Core::getCurrentWorkingDir() + "/actions_history.xml", tr("XML Files (*.xml)"));
+
+    QFile *outputFile = new QFile(outputFileName);
+    if(outputFile->open(QFile::WriteOnly))
+    {
+        QTextStream out(outputFile);
+        out << xml;
+    }
+    else
+        cerr << "Error opening file: " + outputFileName.toStdString() + " for writing.";
+}
 
 
 
 }
+
+
+
+
