@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,6 +35,7 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QStack>
+#include <QList>
 
 class vtkObject;
 namespace camitk {
@@ -43,9 +44,13 @@ class ActionExtension;
 class Action;
 class HistoryItem;
 
-/** The generic/default application.
+/** 
+ * @ingroup group_sdk_libraries_core_application
+ * 
+ * @brief
+ * The generic/default application.
  *  Once this class is intanciated in the main, everything is setup.
- *  The constructor can take the command line arguments (and parse it for the "noConsole" flag).
+ *  The constructor can take the command line arguments.
  *  It can also be asked not to load the extensions automatically,see Application().
  *
  *  If you do not have a specific MainWindow extension, then the default CamiTK MainWindow is used, see setMainWindow()
@@ -284,7 +289,7 @@ public:
     static void vtkProgressFunction(vtkObject* caller, long unsigned int eventId, void* clientData, void* callData);
     ///@}
 
-    ///@name actions pipeline history
+    ///@name Actions pipeline history
     ///@{
     /** Add the history item to the application history.
      * The item is added to the history stack of actions used in a pipeline
@@ -297,6 +302,12 @@ public:
      * @see addHistoryItem() To push back the item use 
      */
     static HistoryItem removeLastHistoryItem();
+    
+    /**
+     * Save the history as an SCXML file, stored using @see addHistoryItem() method.
+     * This file can be interpreted by the camitk actionstatemachine executable
+     */
+    static void saveHistoryAsSXML();
 
     ///@}
 
@@ -396,7 +407,7 @@ private:
     ///@}
 
 
-    ///@name actions pipeline history
+    ///@name Actions pipeline history
     ///@{
     /// get the history of actions stored.
     /// * This method follows the "construct on first use" idiom/design-pattern.
