@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -27,6 +27,7 @@
 #include "Component.h"
 #include "Viewer.h"
 #include "Log.h"
+#include "Property.h"
 #include "Application.h"
 #include "Action.h"
 
@@ -81,6 +82,11 @@ Component::~Component() {
     // remove from selection
     if ( isSelectedFlag )
         setSelected ( false, false );
+    
+    // delete all properties
+    foreach(Property* prop, propertyMap.values())
+        delete prop;
+    propertyMap.clear();
 }
 
 // -------------------- init --------------------
@@ -152,18 +158,35 @@ void Component::updateProperty(QString name, QVariant value) {
 
 // ---------------------- setDynamicProperty ----------------------------
 bool Component::setDynamicProperty(const char* name, const QVariant& value, const char* description, bool isReadOnly) {
-    // to check if static property exists: getPropertyObject()->metaObject()->indexOfProperty(name)>=0
-    // to check if dynamic property exists getPropertyObject()->dynamicPropertyNames().contains(name)
-    // TODO
-    //   - call QObject setProperty
-    //   - if description is not empty: modify description
-    //   - modify readOnly property
-
-    // it is essential to give everything to the property object (by default it is this instance, but it can be otherwise
-    // if the Component subclass has a specific property class)
-    return getPropertyObject()->setProperty(name,value);
+    // the property already exists, change the desciption and readOnly status
+    if (propertyMap.contains(name)) {
+        propertyMap[name]->setDescription(description);
+        propertyMap[name]->setReadOnly(isReadOnly);
+        return getPropertyObject()->setProperty(name,value);
+    }
+    else {
+        // the dynamic property does not exist => create a camitk::Property
+        Property *dynProp = new Property(name,QVariant(value),description,"");
+        dynProp->setReadOnly(isReadOnly);
+        return addProperty(dynProp);
+    }
 }
 
+// ---------------------- getProperty ----------------------------
+Property* Component::getProperty(QString name) {
+    return propertyMap.value(name);
+}
+
+// ---------------------- addProperty ----------------------------
+bool Component::addProperty(Property * prop) {
+    // add a dynamic Qt Meta Object property with the same name
+    bool returnStatus = QObject::setProperty(prop->getName().toStdString().c_str(), prop->getInitialValue() );
+    // add to the map
+    propertyMap.insert(prop->getName(),prop);
+    
+    return returnStatus;
+}
+    
 // -------------------- isTopLevel --------------------
 bool Component::isTopLevel() const {
     return ( myParentNode == NULL );
@@ -404,7 +427,7 @@ void Component::getActorColor ( InterfaceGeometry::RenderingModes m, double d[4]
 }
 
 // -------------------- getBounds --------------------
-void Component::getBounds ( double bounds[6] ) {
+void Component::getBounds ( double *bounds ) {
     invoke1 ( myGeometry, getBounds, bounds )
     else {
         bounds[0] = bounds[2] = bounds[4] = 0.0;
