@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -55,10 +55,10 @@ class vtkDataSetToUnstructuredGridFilter;
 class vtkWindowLevelLookupTable;
 
 // -----------------------------------------------------------------------
-//                                                                         
-//                           Delegation macros                             
-//                     (And your dream comes true)                         
-//                                                                         
+//
+//                           Delegation macros
+//                     (And your dream comes true)
+//
 // -----------------------------------------------------------------------
 
 /** invoke macros:
@@ -252,7 +252,12 @@ class Slice;
 class Viewer;
 
 
-/** A Component represents something that
+/** 
+* 
+* @ingroup group_sdk_libraries_core_component
+* 
+* @brief 
+* A Component represents something that
 * could be included in the explorer view, the interactive 3D viewer,
 * and that could have or not a contextual
 * popup menu (open by a right click in the explorer),
@@ -364,7 +369,7 @@ public:
     /// Check if this data component is selected
     virtual bool isSelected() const;
 
-    /** Update the selection flag. 
+    /** Update the selection flag.
      * @param b the value of the flag (true means "is selected")
      * @param recursive if true (default), also updates the children Component selection flags.
      */
@@ -380,7 +385,7 @@ public:
     bool event(QEvent* e);
 
     /** Get a QMenu that contains all the action that can be applied to this component + the popup menu (if exists).
-     * This method will be soon obsolete and be replaced by getPopupMenu, which will not be maintain in its current
+     * This method will be soon deprecated and be replaced by getPopupMenu, which will not be maintain in its current
      * version). You are encourage to build Action not getPopupMenu() anymore.
      */
     QMenu * getActionAndPopupMenu();
@@ -397,15 +402,44 @@ public:
     /// Assert that a Component instance really inherits from a given className
     bool isInstanceOf(QString className);
 
-    /** get the property widget to display.
-     * (always return NULL, overwrite this method if you want to give here you own widget)
+    ///@cond
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0
+    /**
+     * Get the property widget to display.
+     * This method always returns NULL, overwrite this method if you want to give here you own widget.
+     * @deprecated
+     *  This method is deprecated.\n
+     *  Use getPropertyWidgetAt() and getNumberOfPropertyWidget() instead.
      * @see PropertyExplorer
      */
     virtual QWidget * getPropertyWidget(QWidget* parent = 0) {
         return NULL;
     }
+    ///@endcond
 
-    /** get the property object that could be understood by PropertyEditor.
+    /**
+     * get the number of alternative property widgets
+     * @see PropertyExplorer
+     */
+    virtual unsigned int getNumberOfPropertyWidget() {
+        if (this->getPropertyWidget())
+            return 1;
+        else
+            return 0;
+    }
+
+    /**
+     * Get the ith alternative property widget
+     * @see PropertyExplorer
+     */
+    virtual QWidget * getPropertyWidgetAt(unsigned int i, QWidget* parent = 0) {
+        if (this->getPropertyWidget() && (i==0))
+            return this->getPropertyWidget();
+        else
+            return NULL;
+    }
+
+    /** Get the property object that could be understood by PropertyEditor.
      *  Returns this as any Component instance can manage its list of dynamic properties (and Component inherits
      *  from InterfaceProperty ).
      *  You can also have a separate class to manage your Component properties. In this case, just overide this
@@ -425,16 +459,42 @@ public:
      */
     void updateProperty(QString name, QVariant value);
 
+    ///@cond
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0    
     /** specific setProperty method that can pass the description and the readOnly property.
      *  If the property already exists, it will just change its value (and descripion or readOnly property).
+     * @deprecated
+     *  This method is deprecated.\n
+     *  Use addProperty(Property *) instead.
+     * 
      *  @param name the name of the property
      *  @param value the new value for the given property
      *  @param description the description associated with this property
      *  @param isReadOnly if true, then the property cannot be modified in the GUI
+     *  @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated
      */
     virtual bool setDynamicProperty(const char *name, const QVariant &value, const char *description = "", bool isReadOnly=false);
     ///@}
-
+    ///@endcond
+    
+    /** Get a Property given its name
+     *  @param name the property name
+     *  @return NULL if the name does not match any property name
+     * 
+     *  @see Property
+     */
+    Q_INVOKABLE virtual Property* getProperty(QString name);
+    
+    /** Add a new CamiTK property to the component.
+     * If the property already exist, it will just change its value.
+     * 
+     * \note
+     * The component takes ownership of the Property instance.
+     * 
+     * @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated)
+     */
+    virtual bool addProperty(Property*);
+    
     /**
       * @name InterfaceNode
       * All the implemented InterfaceNode methods
@@ -494,50 +554,50 @@ public:
 
     delegateGet1(myGeometry, getActor, vtkSmartPointer<vtkActor>, const RenderingModes)
 
-	// TODO : uses an object myRepresentation (which is a Geometry or a Slice)
-	// to use a single delegate macro
-	virtual vtkSmartPointer<vtkProp> getProp(const QString &param)
-	{
-		if (myGeometry)
-			return myGeometry->getProp(param);
-		else if(mySlice)
-			return mySlice->getProp(param);
-		return NULL;
-	}
-		
-	virtual unsigned int getNumberOfProp() const { 
-		if (myGeometry)
-			return myGeometry->getNumberOfProp();
-		else if (mySlice)
-			return mySlice->getNumberOfProp();
-		return 0;
-	}
-	
-	virtual vtkSmartPointer<vtkProp> getProp(unsigned int index) { 
-		if (myGeometry)
-			return myGeometry->getProp(index);
-		else if (mySlice)
-			return mySlice->getProp(index);
-		return 0;
-	} 
-	
-	virtual bool addProp(const QString &name, vtkSmartPointer<vtkProp> prop) {
-		if (myGeometry)
-			return myGeometry->addProp(name, prop);
-		else if (mySlice)
-			return mySlice->addProp(name, prop);
-		return false;
-	}
-	
+    // TODO : uses an object myRepresentation (which is a Geometry or a Slice)
+    // to use a single delegate macro
+    virtual vtkSmartPointer<vtkProp> getProp(const QString &param)
+    {
+        if (myGeometry)
+            return myGeometry->getProp(param);
+        else if(mySlice)
+            return mySlice->getProp(param);
+        return NULL;
+    }
 
-	virtual bool removeProp(const QString & name) {
-		if (myGeometry)
-			return myGeometry->removeProp(name);
-		else if (mySlice)
-			return mySlice->removeProp(name);
-		return false;
-	}
-	// END TODO
+    virtual unsigned int getNumberOfProp() const {
+        if (myGeometry)
+            return myGeometry->getNumberOfProp();
+        else if (mySlice)
+            return mySlice->getNumberOfProp();
+        return 0;
+    }
+
+    virtual vtkSmartPointer<vtkProp> getProp(unsigned int index) {
+        if (myGeometry)
+            return myGeometry->getProp(index);
+        else if (mySlice)
+            return mySlice->getProp(index);
+        return 0;
+    }
+
+    virtual bool addProp(const QString &name, vtkSmartPointer<vtkProp> prop) {
+        if (myGeometry)
+            return myGeometry->addProp(name, prop);
+        else if (mySlice)
+            return mySlice->addProp(name, prop);
+        return false;
+    }
+
+
+    virtual bool removeProp(const QString & name) {
+        if (myGeometry)
+            return myGeometry->removeProp(name);
+        else if (mySlice)
+            return mySlice->removeProp(name);
+        return false;
+    }
+    // END TODO
 
 
     /** an inherited class can redefine this method something specific.
@@ -553,7 +613,7 @@ public:
     // --
 
     /// compute the object's bounding box [xmin,xmax, ymin,ymax, zmin,zmax], see Component.cpp
-    virtual void getBounds(double bounds[6]);
+    virtual void getBounds(double *bounds);
 
     /** compute the object's bounding sphere radius, @see Component.cpp
       * @return the bounding radius of the Geometry or -1 if there is no Geometry
@@ -588,6 +648,8 @@ public:
 
     delegateAndInvokeChildren1(myGeometry, setOpacity, const double)
 
+    delegate2(myGeometry, setMapperScalarRange, double, double)
+
     delegate1(myGeometry, setTexture, vtkSmartPointer<vtkTexture>)
 
     virtual void setGlyphType(const GlyphTypes type, const double size = 0.0);
@@ -696,6 +758,9 @@ private:
 
     /// the action menu for this component
     QMenu * actionsMenu;
+    
+    /// list of CamiTK property decorating the dynamic properties
+    QMap<QString, Property*> propertyMap;
     ///@}
 
     /** @name Static members
