@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -32,8 +32,14 @@
 
 namespace camitk
 {
+class Property;
 
-/** This class describe what are the methods to implement in order to manage dynamic properties.
+/** 
+ * @ingroup group_sdk_libraries_core_component
+ * 
+ * @brief 
+ * This class describe what are the methods to implement in order to manage dynamic properties.
+ * InterfaceProperty is one of the interfaces implemented by the @ref camitk::Component "Component" class.
  */
 class InterfaceProperty : public QObject {
     Q_OBJECT
@@ -49,20 +55,66 @@ public:
      */
     virtual bool isInstanceOf(QString className) = 0;
 
+    ///@cond
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0    
     /** specific setProperty method that can pass the description and the readOnly property.
      *  If the property already exists, it will just change its value (and descripion or readOnly property).
+     * @deprecated
+     *  This method is deprecated.\n
+     *  Use addProperty(Property *) instead.
      *  @param name the name of the property
      *  @param value the new value for the given property
      *  @param description the description associated with this property
      *  @param isReadOnly if true, then the property cannot be modified in the GUI
+     *  @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated
      */
     virtual bool setDynamicProperty(const char *name, const QVariant &value, const char *description = "", bool isReadOnly=false) = 0;
+    ///@endcond
+
+    /** Get a Property given its name
+     *  @param name the property name
+     *  @return NULL if the name does not match any property name
+     * 
+     *  @see Property
+     */
+    Q_INVOKABLE virtual Property* getProperty(QString name) = 0;
     
-    /** get the property widget to display.
-     * (always return NULL, overwrite this method if you want to give here you own widget)
+    /** Add a new CamiTK property to the component.
+     * If the property already exist, it will just change its value.
+     * 
+     * \note
+     * The component takes ownership of the Property instance.
+     *
+     * @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated)
+     */
+    virtual bool addProperty(Property*) = 0;
+    
+    ///@cond
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0    
+    /** 
+     * Get the property widget to display.
+     * This method always returns NULL, overwrite this method if you want to give here you own widget.
+     * @deprecated
+     *      This method is deprecated. \n
+     *      Use getPropertyWidgetAt() and getNumberOfPropertyWidget() instead.
+     * @see PropertyExplorer
+     **/
+    virtual QWidget * getPropertyWidget(QWidget* parent = 0) = 0;
+    ///@endcond  
+    
+    /**
+     * get the number of alternative property widgets
      * @see PropertyExplorer
      */
-    virtual QWidget * getPropertyWidget(QWidget* parent = 0) = 0;
+    virtual unsigned int getNumberOfPropertyWidget() = 0;
+    
+    /**
+     * get the ith alternative property widget
+     * overwrtite this method and use the method setAccessibleName of 
+     * QWidget if you want alternative widgets
+     * @see PropertyExplorer
+     */
+    virtual QWidget * getPropertyWidgetAt(unsigned int i, QWidget* parent = 0) = 0;
 
     /** get the property object that could be understood by PropertyEditor.
      *  Returns this as any Component instance can manage its list of dynamic properties (and Component inherits
