@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -330,7 +330,7 @@ void Slice::pixelPicked(double x, double y, double z) {
 }
 
 
-void Slice::reslicedToVolumeCoords(const double ijk[3], double xyz[3]) {
+void Slice::reslicedToVolumeCoords(const double *ijk, double *xyz) {
     // At this point, coordinates are expressed in reslice frame NOT in real frame.
     double localPoint[4];
     double realPoint[4];
@@ -348,7 +348,7 @@ void Slice::reslicedToVolumeCoords(const double ijk[3], double xyz[3]) {
     xyz[2] = realPoint[2];
 }
 
-void Slice::volumeToReslicedCoords(const double xyz[3], double ijk[3]) {
+void Slice::volumeToReslicedCoords(const double *xyz, double *ijk) {
     // At this point, coordinates are expressed in original frame NOT in real frame.
     double realPoint[4];
     double localPoint[4];
