@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -253,6 +253,19 @@ QVariantMap ImageComponent::getImageSize() const {
     return imageSize;
 }
 
+QString ImageComponent::getDataType() const {
+    QString dataType;
+	
+    if (originalImageData) {
+	    dataType = originalImageData->GetScalarTypeAsString();
+	}
+	else {
+	dataType = "unkown";
+	}
+	
+	return dataType;
+}
+
 // -------------------- getVoxelSize --------------------
 QVector3D ImageComponent::getVoxelSize() const {
     if (originalImageData) {
