@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -32,6 +32,7 @@
 #include "qttreepropertybrowser.h"
 #include "qtbuttonpropertybrowser.h"
 #include "qtpropertybrowser.h"
+#include "qtpropertymanager.h"
 
 // -- QT stuff
 #include <QtCore/QMetaObject>
@@ -44,7 +45,8 @@
 // -- stl stuff
 #include <iostream>
 
-
+//-- CamiTK stuff
+#include "Property.h"
 
 
 namespace camitk {
@@ -205,83 +207,76 @@ QtVariantProperty * ObjectControllerPrivate::buildQtVariantProperty(QString name
         buildProperty = m_readOnlyManager->addProperty ( QVariant::String, name);
         buildProperty->setValue ( QLatin1String ( "< Non Readable >" ) );
     }
-    else
-        if ( isEnumType ) {
-            if ( isFlagType ) {
-                buildProperty = m_manager->addProperty ( QtVariantPropertyManager::flagTypeId(), name );
-                QMap<int, bool> valueMap;
-                QStringList flagNames;
+    else if ( isEnumType ) {
+        if ( isFlagType ) {
+            buildProperty = m_manager->addProperty ( QtVariantPropertyManager::flagTypeId(), name );
+            QMap<int, bool> valueMap;
+            QStringList flagNames;
 
-                for ( int i = 0; i < metaEnum->keyCount(); i++ ) {
-                    int enumValue = metaEnum->value ( i );
+            for ( int i = 0; i < metaEnum->keyCount(); i++ ) {
+                int enumValue = metaEnum->value ( i );
 
-                    if ( !valueMap.contains ( enumValue ) && isPowerOf2 ( enumValue ) ) {
-                        valueMap[enumValue] = true;
-                        flagNames.append ( QLatin1String ( metaEnum->key ( i ) ) );
-                    }
-
-                    buildProperty->setAttribute ( QLatin1String ( "flagNames" ), flagNames );
-                    buildProperty->setValue ( flagToInt ( *metaEnum, value.toInt() ) );
-                }
-            }
-            else {
-                buildProperty = m_manager->addProperty ( QtVariantPropertyManager::enumTypeId(), name);
-                QMap<int, bool> valueMap; // dont show multiple enum values which have the same values
-                QStringList enumNames;
-
-                for ( int i = 0; i < metaEnum->keyCount(); i++ ) {
-                    int value = metaEnum->value ( i );
-
-                    if ( !valueMap.contains ( value ) ) {
-                        valueMap[value] = true;
-                        enumNames.append ( QLatin1String ( metaEnum->key ( i ) ) );
-                    }
+                if ( !valueMap.contains ( enumValue ) && isPowerOf2 ( enumValue ) ) {
+                    valueMap[enumValue] = true;
+                    flagNames.append ( QLatin1String ( metaEnum->key ( i ) ) );
                 }
 
-                buildProperty->setAttribute ( QLatin1String ( "enumNames" ), enumNames );
-                buildProperty->setValue ( enumToInt ( *metaEnum, value.toInt() ) );
+                buildProperty->setAttribute ( QLatin1String ( "flagNames" ), flagNames );
+                buildProperty->setValue ( flagToInt ( *metaEnum, value.toInt() ) );
             }
         }
+        else {
+            buildProperty = m_manager->addProperty ( QtVariantPropertyManager::enumTypeId(), name);
+            QMap<int, bool> valueMap; // dont show multiple enum values which have the same values
+            QStringList enumNames;
+
+            for ( int i = 0; i < metaEnum->keyCount(); i++ ) {
+                int value = metaEnum->value ( i );
+
+                if ( !valueMap.contains ( value ) ) {
+                    valueMap[value] = true;
+                    enumNames.append ( QLatin1String ( metaEnum->key ( i ) ) );
+                }
+            }
+
+            buildProperty->setAttribute ( QLatin1String ( "enumNames" ), enumNames );
+            buildProperty->setValue ( enumToInt ( *metaEnum, value.toInt() ) );
+        }
+    }
+    else if ( m_manager->isPropertyTypeSupported ( type ) ) {
+        if ( !isWritable ) {
+            buildProperty = m_readOnlyManager->addProperty ( type,  name);
+        }
+        else if ( !isDesignable )
+            buildProperty = m_readOnlyManager->addProperty ( type, name + " (Non Designable)" );
         else
-            if ( m_manager->isPropertyTypeSupported ( type ) ) {
-                if ( !isWritable ) {
-                    buildProperty = m_readOnlyManager->addProperty ( type,  name + "*" );
-                }
-                else
-                    if ( !isDesignable )
-                        buildProperty = m_readOnlyManager->addProperty ( type, name + " (Non Designable)" );
-                    else
-                        buildProperty = m_manager->addProperty ( type, name );
+            buildProperty = m_manager->addProperty ( type, name );
 
-                buildProperty->setValue ( value );
+        buildProperty->setValue ( value );
+    }
+    else {
+        // a map is managed as a group
+        if ( type == QMetaType::QVariantMap) {
+            QString mapName = name;
+
+            buildProperty = m_manager->addProperty(QtVariantPropertyManager::groupTypeId(), mapName);
+            // build the subproperties
+            QMapIterator<QString, QVariant> it(value.toMap());
+
+            while (it.hasNext()) {
+                it.next();
+                QtVariantProperty *mapSubProperty = buildQtVariantProperty(it.key(), (QMetaType::Type)it.value().userType(), it.value(), isReadable, isWritable, false, false, isDesignable);
+
+                buildProperty->addSubProperty(mapSubProperty);
             }
-            else {
-                // a map is managed as a group
-                if ( type == QMetaType::QVariantMap) {
-                    QString mapName = name;
 
-                    if ( !isWritable ) {
-                        mapName += "*";
-                    }
-
-                    buildProperty = m_manager->addProperty(QtVariantPropertyManager::groupTypeId(), mapName);
-                    // build the subproperties
-                    QMapIterator<QString, QVariant> it(value.toMap());
-
-                    while (it.hasNext()) {
-                        it.next();
-                        QtVariantProperty *mapSubProperty = buildQtVariantProperty(it.key(), (QMetaType::Type)it.value().userType(), it.value(), isReadable, isWritable, false, false, isDesignable);
-
-                        buildProperty->addSubProperty(mapSubProperty);
-                    }
-
-                }
-                else {
-                    buildProperty = m_readOnlyManager->addProperty ( QVariant::String, name );
-                    buildProperty->setValue ( QLatin1String ( "< Unknown Type >" ) );
-                    buildProperty->setEnabled ( false );
-                }
-            }
+        }
+        else {
+            buildProperty = m_readOnlyManager->addProperty ( QVariant::String, name );
+            buildProperty->setValue ( QLatin1String ( "< Unknown Type >" ) );
+            buildProperty->setEnabled ( false );
+        }
+    }
 
     return buildProperty;
 }
@@ -355,21 +350,102 @@ void ObjectControllerPrivate::updateDynamicProperties ( const QObject *edited )
 
 // CAMITK ADDED
 // loop on dynamically added property
-void ObjectControllerPrivate::addDynamicProperties ( const QObject *edited ) {
+void ObjectControllerPrivate::addDynamicProperties ( QObject *edited ) {
 
     QList<QByteArray> dynProp = edited->dynamicPropertyNames();
 
+    // loop on all dynamic properties
     for ( int idx = 0; idx < dynProp.size(); ++idx ) {
         QString pName = QString ( dynProp.at ( idx ) );
         QVariant pValue = edited->property ( dynProp.at ( idx ) );
-        QtVariantProperty *subProperty = 0;
-        subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, true, false, false, true);
+        QtVariantProperty  *subProperty = 0;
+        QtProperty *groupProperty = NULL;
+        
+        // check if the edited object use a list of camitk::Property to
+        // add more information about the dynamic property
+        Property* camitkProp = NULL;
+        bool getPropertyExist = QMetaObject::invokeMethod(edited, "getProperty", Qt::DirectConnection,
+                                Q_RETURN_ARG(Property*, camitkProp),
+                                Q_ARG(QString, pName));
 
-        m_topLevelProperties.append ( subProperty );
-        m_browser->addProperty ( subProperty );
+        if (!getPropertyExist || camitkProp==NULL) {
+            // the old way, build a simple dynamic variant property
+            subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, /* isWritable*/ true, false, false, true);
+        }
+        else {
+            //-- use all the power of the camitk::Property
+            // get then meta enum if available
+            if (!camitkProp->getEnumTypeName().isNull()) {
+                const QMetaObject* metaObj = edited->metaObject();
+                QMetaEnum enumType = metaObj->enumerator(metaObj->indexOfEnumerator(camitkProp->getEnumTypeName().toStdString().c_str()));
+
+                // Create the dynamic variant property + use the read only status
+                subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, /* isWritable*/ !camitkProp->getReadOnly(), true, false, true, &enumType);
+            }
+            else {
+                // Create the dynamic variant property + use the read only status
+                subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, /* isWritable*/ !camitkProp->getReadOnly(), false, false, true);
+            }
+
+            // loop on all property attributes and transfer the values to subProperty
+            foreach(QString attributeName, camitkProp->getAttributeList()) {
+                subProperty->setAttribute( attributeName, camitkProp->getAttribute( attributeName ) );
+            }
+
+
+/*
+            // check if we can add icons
+            if (!camitkProp->getReadOnly() && !camitkProp->getEnumTypeName().isNull() && camitkProp->getEnumIcons().size()>0) {
+                std::cout << "mgr=" << subProperty->propertyManager() << std::endl;
+                QtEnumPropertyManager *testmgr = dynamic_cast<QtEnumPropertyManager*>(subProperty->propertyManager());
+                std::cout << "testmgr=" << testmgr << std::endl;
+                //m_browser->setFactoryForManager<>();
+                std::cout << "mgr class=" << subProperty->propertyManager()->metaObject()->className() << std::endl;
+                std::cout << "camitkProp->getEnumIcons().size()" << camitkProp->getEnumIcons().size() << std::endl;
+                QVariantMap vmap = camitkProp->getEnumIcons();
+                m_manager->setAttribute(subProperty,"enumIcons", vmap);
+                //m_manager->setUserData();
+                //std::cout << "yep..." << std::endl;
+               
+            }
+
+*/
+            // use description for tool tip and what's this
+            QString description = camitkProp->getDescription();
+            subProperty->setWhatsThis(description);
+            subProperty->setToolTip(description);
+
+            // remove rich-text for status tip string (using a reg exp)
+            subProperty->setStatusTip(description.remove(QRegExp("<[^>]*>")));
+            
+            //-- check for subgroup
+            if (!camitkProp->getGroupName().isNull()) {
+                // check if the group property already exists
+                groupProperty = groupProperties.value(camitkProp->getGroupName());
+                if (!groupProperty) {
+                    // create the group property
+                    groupProperty = m_manager->addProperty(QtVariantPropertyManager::groupTypeId(), camitkProp->getGroupName());
+                    //m_classToProperty[metaObject] = classProperty;
+                    //m_propertyToClass[classProperty] = metaObject;
+                    // register it
+                    groupProperties.insert(camitkProp->getGroupName(), groupProperty);
+                    // add to the top level browser
+                    m_topLevelProperties.append(groupProperty);
+                    m_browser->addProperty(groupProperty);
+                }
+                groupProperty->addSubProperty(subProperty);
+            }
+        }
+
+        if (!groupProperty) {
+            // add the variant property to the property and build the matching GUI
+            m_topLevelProperties.append ( subProperty );
+            m_browser->addProperty ( subProperty );
+        }
 
         m_dynamicPropertyToIndex[subProperty] = idx;
         m_indexToDynamicProperty[idx] = subProperty;
+
     }
 
 
@@ -477,6 +553,10 @@ void ObjectController::setObject ( QObject *object ) {
         }
 
         d_ptr->m_topLevelProperties.clear();
+        
+        // all the QtProperty instances are delete, just clear the groupProperties map (no need to delete)
+        d_ptr->groupProperties.clear();
+
     }
 
     d_ptr->m_object = object;
@@ -499,12 +579,12 @@ QObject *ObjectController::object() const {
 // CAMITK ADDED
 void ObjectController::setAutoUpdateProperty(bool autoUpdate) {
     if (autoUpdate) {
-      connect ( d_ptr->m_manager, SIGNAL ( valueChanged ( QtProperty *, const QVariant & ) ),
-              this, SLOT ( valueChanged ( QtProperty *, const QVariant & ) ) );
+        connect ( d_ptr->m_manager, SIGNAL ( valueChanged ( QtProperty *, const QVariant & ) ),
+                  this, SLOT ( valueChanged ( QtProperty *, const QVariant & ) ) );
     }
     else {
-      connect ( d_ptr->m_manager, SIGNAL ( valueChanged ( QtProperty *, const QVariant & ) ),
-              this, SLOT ( saveChange ( QtProperty *, const QVariant & ) ) );
+        connect ( d_ptr->m_manager, SIGNAL ( valueChanged ( QtProperty *, const QVariant & ) ),
+                  this, SLOT ( saveChange ( QtProperty *, const QVariant & ) ) );
     }
 }
 
@@ -518,10 +598,9 @@ void ObjectController::setViewMode ( ViewMode viewMode ) {
         if ( currentViewMode == TREE ) {    // in view mode TREE, the layout contains the property browser
             layout->removeWidget ( d_ptr->m_browser );
         }
-        else
-            if ( currentViewMode == GROUPBOX || currentViewMode == BUTTON ) { // whereas in view mode BUTTON and GROUPBOX, the layout contains the scroll wich contains the property browser
-                layout->removeWidget ( scroll );
-            }
+        else if ( currentViewMode == GROUPBOX || currentViewMode == BUTTON ) { // whereas in view mode BUTTON and GROUPBOX, the layout contains the scroll wich contains the property browser
+            layout->removeWidget ( scroll );
+        }
 
         // just delete to re use the same address for the new property browser
         delete d_ptr->m_browser;
@@ -536,23 +615,23 @@ void ObjectController::setViewMode ( ViewMode viewMode ) {
 
 void ObjectController::initViewMode() {
     switch ( currentViewMode) {
-        case GROUPBOX :
-            d_ptr->m_browser = new QtGroupBoxPropertyBrowser ( this );
-            layout->addWidget ( scroll );
-            scroll->setWidget ( d_ptr->m_browser );
-            break;
-        case BUTTON :
-            d_ptr->m_browser = new QtButtonPropertyBrowser ( this );
-            layout->addWidget ( scroll );
-            scroll->setWidget ( d_ptr->m_browser );
-            break;
-        case TREE :
-        default :
-            d_ptr->m_browser = new QtTreePropertyBrowser ( this );
-            dynamic_cast<QtTreePropertyBrowser*> ( d_ptr->m_browser )->setRootIsDecorated ( false );
-            dynamic_cast<QtTreePropertyBrowser*> ( d_ptr->m_browser )->setResizeMode(QtTreePropertyBrowser::Interactive);
-            layout->addWidget ( d_ptr->m_browser );
-            break;
+    case GROUPBOX :
+        d_ptr->m_browser = new QtGroupBoxPropertyBrowser ( this );
+        layout->addWidget ( scroll );
+        scroll->setWidget ( d_ptr->m_browser );
+        break;
+    case BUTTON :
+        d_ptr->m_browser = new QtButtonPropertyBrowser ( this );
+        layout->addWidget ( scroll );
+        scroll->setWidget ( d_ptr->m_browser );
+        break;
+    case TREE :
+    default :
+        d_ptr->m_browser = new QtTreePropertyBrowser ( this );
+        dynamic_cast<QtTreePropertyBrowser*> ( d_ptr->m_browser )->setRootIsDecorated ( false );
+        dynamic_cast<QtTreePropertyBrowser*> ( d_ptr->m_browser )->setResizeMode(QtTreePropertyBrowser::Interactive);
+        layout->addWidget ( d_ptr->m_browser );
+        break;
     }
 }
 
