@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -1351,12 +1351,12 @@ bool InteractiveViewer::getGradientBackground() const {
 }
 
 //--------------------- getBounds -------------------
-void InteractiveViewer::getBounds(double bounds[6]) {
+void InteractiveViewer::getBounds(double *bounds) {
     rendererWidget->computeVisiblePropBounds(bounds);
 }
 
 //--------------------- getBoundsOfSelected -------------------
-void InteractiveViewer::getBoundsOfSelected(double bounds[6]) {
+void InteractiveViewer::getBoundsOfSelected(double *bounds) {
     // booleen which allows to know if at least 1 element is selected
     bool oneElementSelected = false;
 
