@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -72,6 +72,9 @@ protected:
 };
 
 /**
+  * @ingroup group_sdk_libraries_core_viewer
+  * 
+  * @brief
   * InteractiveViewer is used to view 3D objects and slices (anything that provides either a InterfaceBitMap
   * or a InterfaceGeometry).
   *
@@ -341,10 +344,10 @@ public:
     void initPicking ( PickingMode );
 
     /// Compute the bounding box of the selected elements [xmin,xmax, ymin,ymax, zmin,zmax]
-    void getBoundsOfSelected ( double bound[6] );
+    void getBoundsOfSelected ( double *bound );
 
     /// Compute the bounding box of all displayed Component
-    void getBounds ( double bound[6] );
+    void getBounds ( double *bound );
 
     /// set the slice viewer side bar+screenshot button visibility
     void setSideFrameVisible(bool);
