@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -80,10 +80,13 @@ void PropertyExplorer::refresh(Viewer *whoIsAsking) {
       //-- update currentComponent
       currentComponent = Application::getSelectedComponents().last();
       currentComponent->setVisibility(this, true);
-      //-- get the property widget
-      QWidget * customWidget = currentComponent->getPropertyWidget();
-      if (customWidget) {
-        tabWidget->addTab(customWidget, QString(currentComponent->getName() + " Properties"));
+      //-- get the property widgets
+      QWidget * customWidget;
+      for (unsigned int i=0; i<currentComponent->getNumberOfPropertyWidget(); i++) {
+          customWidget = currentComponent->getPropertyWidgetAt(i);
+          if (customWidget) {
+              tabWidget->addTab(customWidget, customWidget->objectName());
+          }
       }
     }
     //--  update the property editor
