@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -833,7 +833,7 @@ void RendererWidget::actorTransform(vtkSmartPointer<vtkActor> actor, double *box
 }
 
 // ----------------------- computeVisiblePropBounds -----------------------
-void RendererWidget::computeVisiblePropBounds(double bounds[6]) {
+void RendererWidget::computeVisiblePropBounds(double *bounds) {
     renderer->ComputeVisiblePropBounds(bounds);
 }
 
@@ -927,7 +927,7 @@ void RendererWidget::resetCamera() {
     update();
 }
 
-void RendererWidget::resetCamera(double bounds[6]) {
+void RendererWidget::resetCamera(double *bounds) {
     resetCameraSettings();
 
     // set the proper bound
@@ -967,7 +967,7 @@ void RendererWidget::resetCameraSettings() {
 }
 
 // --------------------- getCameraSettings ----------------------
-void RendererWidget::getCameraSettings(double position[3], double focalPoint[3], double viewUp[3]) {
+void RendererWidget::getCameraSettings(double *position, double *focalPoint, double *viewUp) {
     vtkSmartPointer<vtkCamera> cam = renderer->GetActiveCamera();
 
     cam->GetPosition(position);
