@@ -313,11 +313,13 @@ void QtButtonPropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBr
 
     newItem->label = new QLabel(parentWidget);
     newItem->label->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
+    // if createEditor returns null -> there is no editor -> the property is read only
     newItem->widget = createEditor(index->property(), parentWidget);
     if (newItem->widget) {
         QObject::connect(newItem->widget, SIGNAL(destroyed()), q_ptr, SLOT(slotEditorDestroyed()));
         m_widgetToItem[newItem->widget] = newItem;
     } else if (index->property()->hasValue()) {
+        // if the property is read only, create a widget label to show the property value
         newItem->widgetLabel = new QLabel(parentWidget);
         newItem->widgetLabel->setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed));
     }
@@ -463,6 +465,8 @@ void QtButtonPropertyBrowserPrivate::updateItem(WidgetItem *item)
     if (item->button) {
         QFont font = item->button->font();
         font.setUnderline(property->isModified());
+        // if the item->widget is NULL, then the property is read only
+        font.setItalic(!item->widget);
         item->button->setFont(font);
         item->button->setText(property->propertyName());
         item->button->setToolTip(property->toolTip());
@@ -473,6 +477,8 @@ void QtButtonPropertyBrowserPrivate::updateItem(WidgetItem *item)
     if (item->label) {
         QFont font = item->label->font();
         font.setUnderline(property->isModified());
+        // if the item->widget is NULL, then the property is read only
+        font.setItalic(!item->widget);
         item->label->setFont(font);
         item->label->setText(property->propertyName());
         item->label->setToolTip(property->toolTip());
@@ -482,18 +488,20 @@ void QtButtonPropertyBrowserPrivate::updateItem(WidgetItem *item)
     }
     if (item->widgetLabel) {
         QFont font = item->widgetLabel->font();
+        // if the item->widget is NULL, then the property is read only
+        font.setItalic(!item->widget);
         font.setUnderline(false);
         item->widgetLabel->setFont(font);
-        item->widgetLabel->setText(property->valueText());
-        item->widgetLabel->setToolTip(property->valueText());
-        item->widgetLabel->setEnabled(property->isEnabled());
+        item->widgetLabel->setText("\t" + property->valueText());
+        item->widgetLabel->setToolTip(property->toolTip());
+        item->widgetLabel->setEnabled(property->isEnabled());        
     }
     if (item->widget) {
         QFont font = item->widget->font();
-        font.setUnderline(false);
+        font.setUnderline(false);        
         item->widget->setFont(font);
-        item->widget->setEnabled(property->isEnabled());
-        item->widget->setToolTip(property->valueText());
+        item->widget->setEnabled(property->isEnabled());        
+        item->widget->setToolTip(property->toolTip());
     }
 }
 
