@@ -412,6 +412,8 @@ void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item)
     if (item->groupBox) {
         QFont font = item->groupBox->font();
         font.setUnderline(property->isModified());
+        // if the item->widget is NULL, then the property is read only
+        font.setItalic(!item->widget);
         item->groupBox->setFont(font);
         item->groupBox->setTitle(property->propertyName());
         item->groupBox->setToolTip(property->toolTip());
@@ -422,6 +424,8 @@ void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item)
     if (item->label) {
         QFont font = item->label->font();
         font.setUnderline(property->isModified());
+        // if the item->widget is NULL, then the property is read only
+        font.setItalic(!item->widget);        
         item->label->setFont(font);
         item->label->setText(property->propertyName());
         item->label->setToolTip(property->toolTip());
@@ -431,18 +435,22 @@ void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item)
     }
     if (item->widgetLabel) {
         QFont font = item->widgetLabel->font();
+        // if the item->widget is NULL, then the property is read only
+        font.setItalic(!item->widget);     
         font.setUnderline(false);
         item->widgetLabel->setFont(font);
-        item->widgetLabel->setText(property->valueText());
-        item->widgetLabel->setToolTip(property->valueText());
+        item->widgetLabel->setText("\t" + property->valueText());
+        item->widgetLabel->setToolTip(property->toolTip());
         item->widgetLabel->setEnabled(property->isEnabled());
     }
     if (item->widget) {
         QFont font = item->widget->font();
+        // if the item->widget is NULL, then the property is read only
+        font.setItalic(!item->widget);     
         font.setUnderline(false);
         item->widget->setFont(font);
         item->widget->setEnabled(property->isEnabled());
-        item->widget->setToolTip(property->valueText());
+        item->widget->setToolTip(property->toolTip());
     }
     //item->setIcon(1, property->valueIcon());
 }
